# coding: utf-8

"""
    Xero Files API

    These endpoints are specific to Xero Files API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""

"""
    OpenAPI spec version: 2.10.4
"""

import importlib
import re  # noqa: F401

from xero_python import exceptions
from xero_python.api_client import ApiClient, ModelFinder

try:
    from .exception_handler import translate_status_exception
except ImportError:
    translate_status_exception = exceptions.translate_status_exception


class empty:
    """ empty object to mark optional parameter not set """


class FilesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    base_url = "https://api.xero.com/files.xro/1.0"
    models_module = importlib.import_module("xero_python.file.models")

    def __init__(self, api_client=None, base_url=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.base_url = base_url or self.base_url

    def get_resource_url(self, resource_path):
        """
        Combine API base url with resource specific path
        :param str resource_path: API endpoint specific path
        :return: str full resource path
        """
        return self.base_url + resource_path

    def get_model_finder(self):
        return ModelFinder(self.models_module)

    def create_file_association(
        self,
        xero_tenant_id,
        file_id,
        association=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Creates a new file association  # noqa: E501
        OAuth2 scope: files
        By passing in the appropriate options, you can create a new folder  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str file_id: File id for single object (required)
        :param Association association:
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Association
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `create_file_association`"
            )
        # verify the required parameter 'file_id' is set
        if file_id is None:
            raise ValueError(
                "Missing the required parameter `file_id` "
                "when calling `create_file_association`"
            )

        collection_formats = {}
        path_params = {
            "FileId": file_id,
        }

        query_params = []

        header_params = {
            "xero-tenant-id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = association
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Files/{FileId}/Associations")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Association",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "create_file_association")

    def create_folder(
        self,
        xero_tenant_id,
        folder=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Creates a new folder  # noqa: E501
        OAuth2 scope: files
        By passing in the appropriate properties, you can create a new folder  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param Folder folder:
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Folder
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `create_folder`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        header_params = {
            "xero-tenant-id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = folder
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Folders")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Folder",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "create_folder")

    def delete_file(
        self,
        xero_tenant_id,
        file_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Deletes a specific file  # noqa: E501
        OAuth2 scope: files
        Delete a specific file  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str file_id: File id for single object (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: None
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `delete_file`"
            )
        # verify the required parameter 'file_id' is set
        if file_id is None:
            raise ValueError(
                "Missing the required parameter `file_id` " "when calling `delete_file`"
            )

        collection_formats = {}
        path_params = {
            "FileId": file_id,
        }

        query_params = []

        header_params = {
            "xero-tenant-id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Files/{FileId}")

        try:
            return self.api_client.call_api(
                url,
                "DELETE",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type=None,
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "delete_file")

    def delete_file_association(
        self,
        xero_tenant_id,
        file_id,
        object_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Deletes an existing file association  # noqa: E501
        OAuth2 scope: files
        By passing in the appropriate options, you can create a new folder  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str file_id: File id for single object (required)
        :param str object_id: Object id for single object (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: None
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `delete_file_association`"
            )
        # verify the required parameter 'file_id' is set
        if file_id is None:
            raise ValueError(
                "Missing the required parameter `file_id` "
                "when calling `delete_file_association`"
            )
        # verify the required parameter 'object_id' is set
        if object_id is None:
            raise ValueError(
                "Missing the required parameter `object_id` "
                "when calling `delete_file_association`"
            )

        collection_formats = {}
        path_params = {
            "FileId": file_id,
            "ObjectId": object_id,
        }

        query_params = []

        header_params = {
            "xero-tenant-id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Files/{FileId}/Associations/{ObjectId}")

        try:
            return self.api_client.call_api(
                url,
                "DELETE",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type=None,
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "delete_file_association")

    def delete_folder(
        self,
        xero_tenant_id,
        folder_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Deletes a folder  # noqa: E501
        OAuth2 scope: files
        By passing in the appropriate ID, you can delete a folder  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str folder_id: Folder id for single object (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: None
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `delete_folder`"
            )
        # verify the required parameter 'folder_id' is set
        if folder_id is None:
            raise ValueError(
                "Missing the required parameter `folder_id` "
                "when calling `delete_folder`"
            )

        collection_formats = {}
        path_params = {
            "FolderId": folder_id,
        }

        query_params = []

        header_params = {
            "xero-tenant-id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Folders/{FolderId}")

        try:
            return self.api_client.call_api(
                url,
                "DELETE",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type=None,
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "delete_folder")

    def get_associations_by_object(
        self,
        xero_tenant_id,
        object_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves an association object using a unique object ID  # noqa: E501
        OAuth2 scope: files.read
        By passing in the appropriate options,  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str object_id: Object id for single object (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: list[Association]
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_associations_by_object`"
            )
        # verify the required parameter 'object_id' is set
        if object_id is None:
            raise ValueError(
                "Missing the required parameter `object_id` "
                "when calling `get_associations_by_object`"
            )

        collection_formats = {}
        path_params = {
            "ObjectId": object_id,
        }

        query_params = []

        header_params = {
            "xero-tenant-id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Associations/{ObjectId}")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="list[Association]",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_associations_by_object")

    def get_file(
        self,
        xero_tenant_id,
        file_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves a file by a unique file ID  # noqa: E501
        OAuth2 scope: files.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str file_id: File id for single object (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: FileObject
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_file`"
            )
        # verify the required parameter 'file_id' is set
        if file_id is None:
            raise ValueError(
                "Missing the required parameter `file_id` " "when calling `get_file`"
            )

        collection_formats = {}
        path_params = {
            "FileId": file_id,
        }

        query_params = []

        header_params = {
            "xero-tenant-id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Files/{FileId}")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="FileObject",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_file")

    def get_file_associations(
        self,
        xero_tenant_id,
        file_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves a specific file associations  # noqa: E501
        OAuth2 scope: files.read
        By passing in the appropriate options,    # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str file_id: File id for single object (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: list[Association]
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_file_associations`"
            )
        # verify the required parameter 'file_id' is set
        if file_id is None:
            raise ValueError(
                "Missing the required parameter `file_id` "
                "when calling `get_file_associations`"
            )

        collection_formats = {}
        path_params = {
            "FileId": file_id,
        }

        query_params = []

        header_params = {
            "xero-tenant-id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Files/{FileId}/Associations")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="list[Association]",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_file_associations")

    def get_file_content(
        self,
        xero_tenant_id,
        file_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves the content of a specific file  # noqa: E501
        OAuth2 scope: files.read
        By passing in the appropriate options, retrieve data for specific file  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str file_id: File id for single object (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: file
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_file_content`"
            )
        # verify the required parameter 'file_id' is set
        if file_id is None:
            raise ValueError(
                "Missing the required parameter `file_id` "
                "when calling `get_file_content`"
            )

        collection_formats = {}
        path_params = {
            "FileId": file_id,
        }

        query_params = []

        header_params = {
            "xero-tenant-id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/octet-stream"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Files/{FileId}/Content")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="file",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_file_content")

    def get_files(
        self,
        xero_tenant_id,
        pagesize=empty,
        page=empty,
        sort=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves files  # noqa: E501
        OAuth2 scope: files.read
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param int pagesize: pass an optional page size value
        :param int page: number of records to skip for pagination
        :param str sort: values to sort by
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Files
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_files`"
            )

        if pagesize is not empty and pagesize > 100:
            raise ValueError(
                "Invalid value for parameter `pagesize` "
                "when calling `get_files`, must be a value "
                "less than or equal to "
                "`100`"
            )
        if page is not empty and page < 1:
            raise ValueError(
                "Invalid value for parameter `page` "
                "when calling `get_files`, must be a value "
                "greater than or equal to "
                "`1`"
            )
        collection_formats = {}
        path_params = {}

        query_params = []

        if pagesize is not empty:
            query_params.append(("pagesize", pagesize))

        if page is not empty:
            query_params.append(("page", page))

        if sort is not empty:
            query_params.append(("sort", sort))

        header_params = {
            "xero-tenant-id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Files")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Files",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_files")

    def get_folder(
        self,
        xero_tenant_id,
        folder_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves specific folder by using a unique folder ID  # noqa: E501
        OAuth2 scope: files.read
        By passing in the appropriate ID, you can search for specific folder  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str folder_id: Folder id for single object (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Folder
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_folder`"
            )
        # verify the required parameter 'folder_id' is set
        if folder_id is None:
            raise ValueError(
                "Missing the required parameter `folder_id` "
                "when calling `get_folder`"
            )

        collection_formats = {}
        path_params = {
            "FolderId": folder_id,
        }

        query_params = []

        header_params = {
            "xero-tenant-id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Folders/{FolderId}")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Folder",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_folder")

    def get_folders(
        self,
        xero_tenant_id,
        sort=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves folders  # noqa: E501
        OAuth2 scope: files.read
        By passing in the appropriate options, you can search for available folders  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str sort: values to sort by
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: list[Folder]
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_folders`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        if sort is not empty:
            query_params.append(("sort", sort))

        header_params = {
            "xero-tenant-id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Folders")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="list[Folder]",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_folders")

    def get_inbox(
        self,
        xero_tenant_id,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Retrieves inbox folder  # noqa: E501
        OAuth2 scope: files.read
        Search for the user inbox  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Folder
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `get_inbox`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        header_params = {
            "xero-tenant-id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Inbox")

        try:
            return self.api_client.call_api(
                url,
                "GET",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Folder",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "get_inbox")

    def update_file(
        self,
        xero_tenant_id,
        file_id,
        file_object=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Update a file  # noqa: E501
        OAuth2 scope: files
        Updates file properties of a single file  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str file_id: File id for single object (required)
        :param FileObject file_object:
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: FileObject
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `update_file`"
            )
        # verify the required parameter 'file_id' is set
        if file_id is None:
            raise ValueError(
                "Missing the required parameter `file_id` " "when calling `update_file`"
            )

        collection_formats = {}
        path_params = {
            "FileId": file_id,
        }

        query_params = []

        header_params = {
            "xero-tenant-id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = file_object
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Files/{FileId}")

        try:
            return self.api_client.call_api(
                url,
                "PUT",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="FileObject",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "update_file")

    def update_folder(
        self,
        xero_tenant_id,
        folder_id,
        folder,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Updates an existing folder  # noqa: E501
        OAuth2 scope: files
        By passing in the appropriate ID and properties, you can update a folder  # noqa: E501
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str folder_id: Folder id for single object (required)
        :param Folder folder: (required)
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: Folder
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `update_folder`"
            )
        # verify the required parameter 'folder_id' is set
        if folder_id is None:
            raise ValueError(
                "Missing the required parameter `folder_id` "
                "when calling `update_folder`"
            )
        # verify the required parameter 'folder' is set
        if folder is None:
            raise ValueError(
                "Missing the required parameter `folder` "
                "when calling `update_folder`"
            )

        collection_formats = {}
        path_params = {
            "FolderId": folder_id,
        }

        query_params = []

        header_params = {
            "xero-tenant-id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = []

        body_params = folder
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Folders/{FolderId}")

        try:
            return self.api_client.call_api(
                url,
                "PUT",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="Folder",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "update_folder")

    def upload_file(
        self,
        xero_tenant_id,
        body,
        name,
        filename,
        mime_type=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Uploads a File to the inbox  # noqa: E501
        OAuth2 scope: files
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str body: (required)
        :param str name: exact name of the file you are uploading (required)
        :param str filename: (required)
        :param str mime_type:
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: FileObject
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `upload_file`"
            )
        # verify the required parameter 'body' is set
        if body is None:
            raise ValueError(
                "Missing the required parameter `body` " "when calling `upload_file`"
            )
        # verify the required parameter 'name' is set
        if name is None:
            raise ValueError(
                "Missing the required parameter `name` " "when calling `upload_file`"
            )
        # verify the required parameter 'filename' is set
        if filename is None:
            raise ValueError(
                "Missing the required parameter `filename` "
                "when calling `upload_file`"
            )

        collection_formats = {}
        path_params = {}

        query_params = []

        header_params = {
            "xero-tenant-id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = [
            ("body", body),
            ("name", name),
            ("filename", filename),
            ("mimeType", mime_type),
        ]

        body_params = None
        body_params = body
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["multipart/form-data"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Files")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="FileObject",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "upload_file")

    def upload_file_to_folder(
        self,
        xero_tenant_id,
        folder_id,
        body,
        name,
        filename,
        mime_type=empty,
        _return_http_data_only=True,
        _preload_content=True,
        _request_timeout=None,
    ):
        """Uploads a File to a specific folder  # noqa: E501
        OAuth2 scope: files
        :param str xero_tenant_id: Xero identifier for Tenant (required)
        :param str folder_id: pass required folder id to save file to specific folder (required)
        :param str body: (required)
        :param str name: exact name of the file you are uploading (required)
        :param str filename: (required)
        :param str mime_type:
        :param bool _return_http_data_only: return received data only
        :param bool _preload_content: load received data in models
        :param bool _request_timeout: maximum wait time for response
        :return: FileObject
        """

        # verify the required parameter 'xero_tenant_id' is set
        if xero_tenant_id is None:
            raise ValueError(
                "Missing the required parameter `xero_tenant_id` "
                "when calling `upload_file_to_folder`"
            )
        # verify the required parameter 'folder_id' is set
        if folder_id is None:
            raise ValueError(
                "Missing the required parameter `folder_id` "
                "when calling `upload_file_to_folder`"
            )
        # verify the required parameter 'body' is set
        if body is None:
            raise ValueError(
                "Missing the required parameter `body` "
                "when calling `upload_file_to_folder`"
            )
        # verify the required parameter 'name' is set
        if name is None:
            raise ValueError(
                "Missing the required parameter `name` "
                "when calling `upload_file_to_folder`"
            )
        # verify the required parameter 'filename' is set
        if filename is None:
            raise ValueError(
                "Missing the required parameter `filename` "
                "when calling `upload_file_to_folder`"
            )

        collection_formats = {}
        path_params = {
            "FolderId": folder_id,
        }

        query_params = []

        header_params = {
            "xero-tenant-id": xero_tenant_id,
        }

        local_var_files = {}
        form_params = [
            ("body", body),
            ("name", name),
            ("filename", filename),
            ("mimeType", mime_type),
        ]

        body_params = None
        body_params = body
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["multipart/form-data"]
        )

        # Authentication setting
        auth_settings = ["OAuth2"]
        url = self.get_resource_url("/Files/{FolderId}")

        try:
            return self.api_client.call_api(
                url,
                "POST",
                path_params,
                query_params,
                header_params,
                body=body_params,
                post_params=form_params,
                files=local_var_files,
                response_type="FileObject",
                response_model_finder=self.get_model_finder(),
                auth_settings=auth_settings,
                _return_http_data_only=_return_http_data_only,
                _preload_content=_preload_content,
                _request_timeout=_request_timeout,
                collection_formats=collection_formats,
            )
        except exceptions.HTTPStatusException as error:
            raise translate_status_exception(error, self, "upload_file_to_folder")



# coding: utf-8

"""
    Xero Payroll UK

    This is the Xero Payroll API for orgs in the UK region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class TaxLine(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "tax_line_id": "str",
        "description": "str",
        "is_employer_tax": "bool",
        "amount": "float",
        "global_tax_type_id": "str",
        "manual_adjustment": "bool",
    }

    attribute_map = {
        "tax_line_id": "taxLineID",
        "description": "description",
        "is_employer_tax": "isEmployerTax",
        "amount": "amount",
        "global_tax_type_id": "globalTaxTypeID",
        "manual_adjustment": "manualAdjustment",
    }

    def __init__(
        self,
        tax_line_id=None,
        description=None,
        is_employer_tax=None,
        amount=None,
        global_tax_type_id=None,
        manual_adjustment=None,
    ):  # noqa: E501
        """TaxLine - a model defined in OpenAPI"""  # noqa: E501

        self._tax_line_id = None
        self._description = None
        self._is_employer_tax = None
        self._amount = None
        self._global_tax_type_id = None
        self._manual_adjustment = None
        self.discriminator = None

        if tax_line_id is not None:
            self.tax_line_id = tax_line_id
        if description is not None:
            self.description = description
        if is_employer_tax is not None:
            self.is_employer_tax = is_employer_tax
        if amount is not None:
            self.amount = amount
        if global_tax_type_id is not None:
            self.global_tax_type_id = global_tax_type_id
        if manual_adjustment is not None:
            self.manual_adjustment = manual_adjustment

    @property
    def tax_line_id(self):
        """Gets the tax_line_id of this TaxLine.  # noqa: E501

        Xero identifier for payroll tax line  # noqa: E501

        :return: The tax_line_id of this TaxLine.  # noqa: E501
        :rtype: str
        """
        return self._tax_line_id

    @tax_line_id.setter
    def tax_line_id(self, tax_line_id):
        """Sets the tax_line_id of this TaxLine.

        Xero identifier for payroll tax line  # noqa: E501

        :param tax_line_id: The tax_line_id of this TaxLine.  # noqa: E501
        :type: str
        """

        self._tax_line_id = tax_line_id

    @property
    def description(self):
        """Gets the description of this TaxLine.  # noqa: E501

        Tax line description  # noqa: E501

        :return: The description of this TaxLine.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this TaxLine.

        Tax line description  # noqa: E501

        :param description: The description of this TaxLine.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def is_employer_tax(self):
        """Gets the is_employer_tax of this TaxLine.  # noqa: E501

        Identifies if the amount is paid for by the employee or employer. True if employer pays the tax  # noqa: E501

        :return: The is_employer_tax of this TaxLine.  # noqa: E501
        :rtype: bool
        """
        return self._is_employer_tax

    @is_employer_tax.setter
    def is_employer_tax(self, is_employer_tax):
        """Sets the is_employer_tax of this TaxLine.

        Identifies if the amount is paid for by the employee or employer. True if employer pays the tax  # noqa: E501

        :param is_employer_tax: The is_employer_tax of this TaxLine.  # noqa: E501
        :type: bool
        """

        self._is_employer_tax = is_employer_tax

    @property
    def amount(self):
        """Gets the amount of this TaxLine.  # noqa: E501

        The amount of the tax line  # noqa: E501

        :return: The amount of this TaxLine.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this TaxLine.

        The amount of the tax line  # noqa: E501

        :param amount: The amount of this TaxLine.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def global_tax_type_id(self):
        """Gets the global_tax_type_id of this TaxLine.  # noqa: E501

        Tax type ID  # noqa: E501

        :return: The global_tax_type_id of this TaxLine.  # noqa: E501
        :rtype: str
        """
        return self._global_tax_type_id

    @global_tax_type_id.setter
    def global_tax_type_id(self, global_tax_type_id):
        """Sets the global_tax_type_id of this TaxLine.

        Tax type ID  # noqa: E501

        :param global_tax_type_id: The global_tax_type_id of this TaxLine.  # noqa: E501
        :type: str
        """

        self._global_tax_type_id = global_tax_type_id

    @property
    def manual_adjustment(self):
        """Gets the manual_adjustment of this TaxLine.  # noqa: E501

        Identifies if the tax line is a manual adjustment  # noqa: E501

        :return: The manual_adjustment of this TaxLine.  # noqa: E501
        :rtype: bool
        """
        return self._manual_adjustment

    @manual_adjustment.setter
    def manual_adjustment(self, manual_adjustment):
        """Sets the manual_adjustment of this TaxLine.

        Identifies if the tax line is a manual adjustment  # noqa: E501

        :param manual_adjustment: The manual_adjustment of this TaxLine.  # noqa: E501
        :type: bool
        """

        self._manual_adjustment = manual_adjustment



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class ReimbursementLine(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "reimbursement_type_id": "str",
        "amount": "float",
        "description": "str",
        "expense_account": "str",
    }

    attribute_map = {
        "reimbursement_type_id": "ReimbursementTypeID",
        "amount": "Amount",
        "description": "Description",
        "expense_account": "ExpenseAccount",
    }

    def __init__(
        self,
        reimbursement_type_id=None,
        amount=None,
        description=None,
        expense_account=None,
    ):  # noqa: E501
        """ReimbursementLine - a model defined in OpenAPI"""  # noqa: E501

        self._reimbursement_type_id = None
        self._amount = None
        self._description = None
        self._expense_account = None
        self.discriminator = None

        if reimbursement_type_id is not None:
            self.reimbursement_type_id = reimbursement_type_id
        if amount is not None:
            self.amount = amount
        if description is not None:
            self.description = description
        if expense_account is not None:
            self.expense_account = expense_account

    @property
    def reimbursement_type_id(self):
        """Gets the reimbursement_type_id of this ReimbursementLine.  # noqa: E501

        Xero reimbursement type identifier  # noqa: E501

        :return: The reimbursement_type_id of this ReimbursementLine.  # noqa: E501
        :rtype: str
        """
        return self._reimbursement_type_id

    @reimbursement_type_id.setter
    def reimbursement_type_id(self, reimbursement_type_id):
        """Sets the reimbursement_type_id of this ReimbursementLine.

        Xero reimbursement type identifier  # noqa: E501

        :param reimbursement_type_id: The reimbursement_type_id of this ReimbursementLine.  # noqa: E501
        :type: str
        """

        self._reimbursement_type_id = reimbursement_type_id

    @property
    def amount(self):
        """Gets the amount of this ReimbursementLine.  # noqa: E501

        Reimbursement type amount  # noqa: E501

        :return: The amount of this ReimbursementLine.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this ReimbursementLine.

        Reimbursement type amount  # noqa: E501

        :param amount: The amount of this ReimbursementLine.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def description(self):
        """Gets the description of this ReimbursementLine.  # noqa: E501

        Reimbursement lines description (max length 50)  # noqa: E501

        :return: The description of this ReimbursementLine.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ReimbursementLine.

        Reimbursement lines description (max length 50)  # noqa: E501

        :param description: The description of this ReimbursementLine.  # noqa: E501
        :type: str
        """
        if description is not None and len(description) > 50:
            raise ValueError(
                "Invalid value for `description`, "
                "length must be less than or equal to `50`"
            )  # noqa: E501

        self._description = description

    @property
    def expense_account(self):
        """Gets the expense_account of this ReimbursementLine.  # noqa: E501

        Reimbursement expense account. For posted pay run you should be able to see expense account code.  # noqa: E501

        :return: The expense_account of this ReimbursementLine.  # noqa: E501
        :rtype: str
        """
        return self._expense_account

    @expense_account.setter
    def expense_account(self, expense_account):
        """Sets the expense_account of this ReimbursementLine.

        Reimbursement expense account. For posted pay run you should be able to see expense account code.  # noqa: E501

        :param expense_account: The expense_account of this ReimbursementLine.  # noqa: E501
        :type: str
        """

        self._expense_account = expense_account



# coding: utf-8

"""
    Xero Payroll UK

    This is the Xero Payroll API for orgs in the UK region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from enum import Enum


class StatutoryDeductionCategory(Enum):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    allowed enum values
    """

    ADDITIONALSTUDENTLOAN = "AdditionalStudentLoan"
    CHILDSUPPORT = "ChildSupport"
    COURTFINES = "CourtFines"
    CREDITOR = "Creditor"
    FEDERALLEVY = "FederalLevy"
    INLANDREVENUEARREARS = "InlandRevenueArrears"
    KIWISAVER = "KiwiSaver"
    MSDREPAYMENTS = "MsdRepayments"
    NONPRIORITYORDER = "NonPriorityOrder"
    PRIORITYORDER = "PriorityOrder"
    TABLEBASED = "TableBased"
    STUDENTLOAN = "StudentLoan"
    VOLUNTARYSTUDENTLOAN = "VoluntaryStudentLoan"
    USCHILDSUPPORT = "USChildSupport"



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class HomeAddress(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "address_line1": "str",
        "address_line2": "str",
        "city": "str",
        "region": "State",
        "postal_code": "str",
        "country": "str",
    }

    attribute_map = {
        "address_line1": "AddressLine1",
        "address_line2": "AddressLine2",
        "city": "City",
        "region": "Region",
        "postal_code": "PostalCode",
        "country": "Country",
    }

    def __init__(
        self,
        address_line1=None,
        address_line2=None,
        city=None,
        region=None,
        postal_code=None,
        country=None,
    ):  # noqa: E501
        """HomeAddress - a model defined in OpenAPI"""  # noqa: E501

        self._address_line1 = None
        self._address_line2 = None
        self._city = None
        self._region = None
        self._postal_code = None
        self._country = None
        self.discriminator = None

        self.address_line1 = address_line1
        if address_line2 is not None:
            self.address_line2 = address_line2
        if city is not None:
            self.city = city
        if region is not None:
            self.region = region
        if postal_code is not None:
            self.postal_code = postal_code
        if country is not None:
            self.country = country

    @property
    def address_line1(self):
        """Gets the address_line1 of this HomeAddress.  # noqa: E501

        Address line 1 for employee home address  # noqa: E501

        :return: The address_line1 of this HomeAddress.  # noqa: E501
        :rtype: str
        """
        return self._address_line1

    @address_line1.setter
    def address_line1(self, address_line1):
        """Sets the address_line1 of this HomeAddress.

        Address line 1 for employee home address  # noqa: E501

        :param address_line1: The address_line1 of this HomeAddress.  # noqa: E501
        :type: str
        """
        if address_line1 is None:
            raise ValueError(
                "Invalid value for `address_line1`, must not be `None`"
            )  # noqa: E501

        self._address_line1 = address_line1

    @property
    def address_line2(self):
        """Gets the address_line2 of this HomeAddress.  # noqa: E501

        Address line 2 for employee home address  # noqa: E501

        :return: The address_line2 of this HomeAddress.  # noqa: E501
        :rtype: str
        """
        return self._address_line2

    @address_line2.setter
    def address_line2(self, address_line2):
        """Sets the address_line2 of this HomeAddress.

        Address line 2 for employee home address  # noqa: E501

        :param address_line2: The address_line2 of this HomeAddress.  # noqa: E501
        :type: str
        """

        self._address_line2 = address_line2

    @property
    def city(self):
        """Gets the city of this HomeAddress.  # noqa: E501

        Suburb for employee home address  # noqa: E501

        :return: The city of this HomeAddress.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this HomeAddress.

        Suburb for employee home address  # noqa: E501

        :param city: The city of this HomeAddress.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def region(self):
        """Gets the region of this HomeAddress.  # noqa: E501


        :return: The region of this HomeAddress.  # noqa: E501
        :rtype: State
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this HomeAddress.


        :param region: The region of this HomeAddress.  # noqa: E501
        :type: State
        """

        self._region = region

    @property
    def postal_code(self):
        """Gets the postal_code of this HomeAddress.  # noqa: E501

        PostCode for employee home address  # noqa: E501

        :return: The postal_code of this HomeAddress.  # noqa: E501
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """Sets the postal_code of this HomeAddress.

        PostCode for employee home address  # noqa: E501

        :param postal_code: The postal_code of this HomeAddress.  # noqa: E501
        :type: str
        """

        self._postal_code = postal_code

    @property
    def country(self):
        """Gets the country of this HomeAddress.  # noqa: E501

        Country of HomeAddress  # noqa: E501

        :return: The country of this HomeAddress.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this HomeAddress.

        Country of HomeAddress  # noqa: E501

        :param country: The country of this HomeAddress.  # noqa: E501
        :type: str
        """

        self._country = country



# coding: utf-8

"""
    Xero Payroll NZ

    This is the Xero Payroll API for orgs in the NZ region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class EmployeeLeaveSetup(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "include_holiday_pay": "bool",
        "holiday_pay_opening_balance": "float",
        "annual_leave_opening_balance": "float",
        "negative_annual_leave_balance_paid_amount": "float",
        "sick_leave_hours_to_accrue_annually": "float",
        "sick_leave_maximum_hours_to_accrue": "float",
        "sick_leave_opening_balance": "float",
    }

    attribute_map = {
        "include_holiday_pay": "includeHolidayPay",
        "holiday_pay_opening_balance": "holidayPayOpeningBalance",
        "annual_leave_opening_balance": "annualLeaveOpeningBalance",
        "negative_annual_leave_balance_paid_amount": "negativeAnnualLeaveBalancePaidAmount",
        "sick_leave_hours_to_accrue_annually": "sickLeaveHoursToAccrueAnnually",
        "sick_leave_maximum_hours_to_accrue": "sickLeaveMaximumHoursToAccrue",
        "sick_leave_opening_balance": "sickLeaveOpeningBalance",
    }

    def __init__(
        self,
        include_holiday_pay=None,
        holiday_pay_opening_balance=None,
        annual_leave_opening_balance=None,
        negative_annual_leave_balance_paid_amount=None,
        sick_leave_hours_to_accrue_annually=None,
        sick_leave_maximum_hours_to_accrue=None,
        sick_leave_opening_balance=None,
    ):  # noqa: E501
        """EmployeeLeaveSetup - a model defined in OpenAPI"""  # noqa: E501

        self._include_holiday_pay = None
        self._holiday_pay_opening_balance = None
        self._annual_leave_opening_balance = None
        self._negative_annual_leave_balance_paid_amount = None
        self._sick_leave_hours_to_accrue_annually = None
        self._sick_leave_maximum_hours_to_accrue = None
        self._sick_leave_opening_balance = None
        self.discriminator = None

        if include_holiday_pay is not None:
            self.include_holiday_pay = include_holiday_pay
        if holiday_pay_opening_balance is not None:
            self.holiday_pay_opening_balance = holiday_pay_opening_balance
        if annual_leave_opening_balance is not None:
            self.annual_leave_opening_balance = annual_leave_opening_balance
        if negative_annual_leave_balance_paid_amount is not None:
            self.negative_annual_leave_balance_paid_amount = (
                negative_annual_leave_balance_paid_amount
            )
        if sick_leave_hours_to_accrue_annually is not None:
            self.sick_leave_hours_to_accrue_annually = (
                sick_leave_hours_to_accrue_annually
            )
        if sick_leave_maximum_hours_to_accrue is not None:
            self.sick_leave_maximum_hours_to_accrue = sick_leave_maximum_hours_to_accrue
        if sick_leave_opening_balance is not None:
            self.sick_leave_opening_balance = sick_leave_opening_balance

    @property
    def include_holiday_pay(self):
        """Gets the include_holiday_pay of this EmployeeLeaveSetup.  # noqa: E501

        Identifier if holiday pay will be included in each payslip  # noqa: E501

        :return: The include_holiday_pay of this EmployeeLeaveSetup.  # noqa: E501
        :rtype: bool
        """
        return self._include_holiday_pay

    @include_holiday_pay.setter
    def include_holiday_pay(self, include_holiday_pay):
        """Sets the include_holiday_pay of this EmployeeLeaveSetup.

        Identifier if holiday pay will be included in each payslip  # noqa: E501

        :param include_holiday_pay: The include_holiday_pay of this EmployeeLeaveSetup.  # noqa: E501
        :type: bool
        """

        self._include_holiday_pay = include_holiday_pay

    @property
    def holiday_pay_opening_balance(self):
        """Gets the holiday_pay_opening_balance of this EmployeeLeaveSetup.  # noqa: E501

        Initial holiday pay balance. A percentage — usually 8% — of gross earnings since their last work anniversary.  # noqa: E501

        :return: The holiday_pay_opening_balance of this EmployeeLeaveSetup.  # noqa: E501
        :rtype: float
        """
        return self._holiday_pay_opening_balance

    @holiday_pay_opening_balance.setter
    def holiday_pay_opening_balance(self, holiday_pay_opening_balance):
        """Sets the holiday_pay_opening_balance of this EmployeeLeaveSetup.

        Initial holiday pay balance. A percentage — usually 8% — of gross earnings since their last work anniversary.  # noqa: E501

        :param holiday_pay_opening_balance: The holiday_pay_opening_balance of this EmployeeLeaveSetup.  # noqa: E501
        :type: float
        """

        self._holiday_pay_opening_balance = holiday_pay_opening_balance

    @property
    def annual_leave_opening_balance(self):
        """Gets the annual_leave_opening_balance of this EmployeeLeaveSetup.  # noqa: E501

        Initial annual leave balance. The balance at their last anniversary, less any leave taken since then and excluding accrued annual leave.  # noqa: E501

        :return: The annual_leave_opening_balance of this EmployeeLeaveSetup.  # noqa: E501
        :rtype: float
        """
        return self._annual_leave_opening_balance

    @annual_leave_opening_balance.setter
    def annual_leave_opening_balance(self, annual_leave_opening_balance):
        """Sets the annual_leave_opening_balance of this EmployeeLeaveSetup.

        Initial annual leave balance. The balance at their last anniversary, less any leave taken since then and excluding accrued annual leave.  # noqa: E501

        :param annual_leave_opening_balance: The annual_leave_opening_balance of this EmployeeLeaveSetup.  # noqa: E501
        :type: float
        """

        self._annual_leave_opening_balance = annual_leave_opening_balance

    @property
    def negative_annual_leave_balance_paid_amount(self):
        """Gets the negative_annual_leave_balance_paid_amount of this EmployeeLeaveSetup.  # noqa: E501

        The dollar value of annual leave opening balance if negative.  # noqa: E501

        :return: The negative_annual_leave_balance_paid_amount of this EmployeeLeaveSetup.  # noqa: E501
        :rtype: float
        """
        return self._negative_annual_leave_balance_paid_amount

    @negative_annual_leave_balance_paid_amount.setter
    def negative_annual_leave_balance_paid_amount(
        self, negative_annual_leave_balance_paid_amount
    ):
        """Sets the negative_annual_leave_balance_paid_amount of this EmployeeLeaveSetup.

        The dollar value of annual leave opening balance if negative.  # noqa: E501

        :param negative_annual_leave_balance_paid_amount: The negative_annual_leave_balance_paid_amount of this EmployeeLeaveSetup.  # noqa: E501
        :type: float
        """

        self._negative_annual_leave_balance_paid_amount = (
            negative_annual_leave_balance_paid_amount
        )

    @property
    def sick_leave_hours_to_accrue_annually(self):
        """Gets the sick_leave_hours_to_accrue_annually of this EmployeeLeaveSetup.  # noqa: E501

        Number of hours accrued annually for sick leave. Multiply the number of days they're entitled to by the hours worked per day  # noqa: E501

        :return: The sick_leave_hours_to_accrue_annually of this EmployeeLeaveSetup.  # noqa: E501
        :rtype: float
        """
        return self._sick_leave_hours_to_accrue_annually

    @sick_leave_hours_to_accrue_annually.setter
    def sick_leave_hours_to_accrue_annually(self, sick_leave_hours_to_accrue_annually):
        """Sets the sick_leave_hours_to_accrue_annually of this EmployeeLeaveSetup.

        Number of hours accrued annually for sick leave. Multiply the number of days they're entitled to by the hours worked per day  # noqa: E501

        :param sick_leave_hours_to_accrue_annually: The sick_leave_hours_to_accrue_annually of this EmployeeLeaveSetup.  # noqa: E501
        :type: float
        """

        self._sick_leave_hours_to_accrue_annually = sick_leave_hours_to_accrue_annually

    @property
    def sick_leave_maximum_hours_to_accrue(self):
        """Gets the sick_leave_maximum_hours_to_accrue of this EmployeeLeaveSetup.  # noqa: E501

        Maximum number of hours accrued annually for sick leave. Multiply the maximum days they can accrue by the hours worked per day  # noqa: E501

        :return: The sick_leave_maximum_hours_to_accrue of this EmployeeLeaveSetup.  # noqa: E501
        :rtype: float
        """
        return self._sick_leave_maximum_hours_to_accrue

    @sick_leave_maximum_hours_to_accrue.setter
    def sick_leave_maximum_hours_to_accrue(self, sick_leave_maximum_hours_to_accrue):
        """Sets the sick_leave_maximum_hours_to_accrue of this EmployeeLeaveSetup.

        Maximum number of hours accrued annually for sick leave. Multiply the maximum days they can accrue by the hours worked per day  # noqa: E501

        :param sick_leave_maximum_hours_to_accrue: The sick_leave_maximum_hours_to_accrue of this EmployeeLeaveSetup.  # noqa: E501
        :type: float
        """

        self._sick_leave_maximum_hours_to_accrue = sick_leave_maximum_hours_to_accrue

    @property
    def sick_leave_opening_balance(self):
        """Gets the sick_leave_opening_balance of this EmployeeLeaveSetup.  # noqa: E501

        Initial sick leave balance. This will be positive unless they've taken sick leave in advance  # noqa: E501

        :return: The sick_leave_opening_balance of this EmployeeLeaveSetup.  # noqa: E501
        :rtype: float
        """
        return self._sick_leave_opening_balance

    @sick_leave_opening_balance.setter
    def sick_leave_opening_balance(self, sick_leave_opening_balance):
        """Sets the sick_leave_opening_balance of this EmployeeLeaveSetup.

        Initial sick leave balance. This will be positive unless they've taken sick leave in advance  # noqa: E501

        :param sick_leave_opening_balance: The sick_leave_opening_balance of this EmployeeLeaveSetup.  # noqa: E501
        :type: float
        """

        self._sick_leave_opening_balance = sick_leave_opening_balance



# coding: utf-8

"""
    Xero Payroll NZ

    This is the Xero Payroll API for orgs in the NZ region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class PaymentLine(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "payment_line_id": "str",
        "amount": "float",
        "account_number": "str",
        "sort_code": "str",
        "account_name": "str",
    }

    attribute_map = {
        "payment_line_id": "paymentLineID",
        "amount": "amount",
        "account_number": "accountNumber",
        "sort_code": "sortCode",
        "account_name": "accountName",
    }

    def __init__(
        self,
        payment_line_id=None,
        amount=None,
        account_number=None,
        sort_code=None,
        account_name=None,
    ):  # noqa: E501
        """PaymentLine - a model defined in OpenAPI"""  # noqa: E501

        self._payment_line_id = None
        self._amount = None
        self._account_number = None
        self._sort_code = None
        self._account_name = None
        self.discriminator = None

        if payment_line_id is not None:
            self.payment_line_id = payment_line_id
        if amount is not None:
            self.amount = amount
        if account_number is not None:
            self.account_number = account_number
        if sort_code is not None:
            self.sort_code = sort_code
        if account_name is not None:
            self.account_name = account_name

    @property
    def payment_line_id(self):
        """Gets the payment_line_id of this PaymentLine.  # noqa: E501

        Xero identifier for payroll payment line  # noqa: E501

        :return: The payment_line_id of this PaymentLine.  # noqa: E501
        :rtype: str
        """
        return self._payment_line_id

    @payment_line_id.setter
    def payment_line_id(self, payment_line_id):
        """Sets the payment_line_id of this PaymentLine.

        Xero identifier for payroll payment line  # noqa: E501

        :param payment_line_id: The payment_line_id of this PaymentLine.  # noqa: E501
        :type: str
        """

        self._payment_line_id = payment_line_id

    @property
    def amount(self):
        """Gets the amount of this PaymentLine.  # noqa: E501

        The amount of the payment line  # noqa: E501

        :return: The amount of this PaymentLine.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this PaymentLine.

        The amount of the payment line  # noqa: E501

        :param amount: The amount of this PaymentLine.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def account_number(self):
        """Gets the account_number of this PaymentLine.  # noqa: E501

        The account number  # noqa: E501

        :return: The account_number of this PaymentLine.  # noqa: E501
        :rtype: str
        """
        return self._account_number

    @account_number.setter
    def account_number(self, account_number):
        """Sets the account_number of this PaymentLine.

        The account number  # noqa: E501

        :param account_number: The account_number of this PaymentLine.  # noqa: E501
        :type: str
        """

        self._account_number = account_number

    @property
    def sort_code(self):
        """Gets the sort_code of this PaymentLine.  # noqa: E501

        The account sort code  # noqa: E501

        :return: The sort_code of this PaymentLine.  # noqa: E501
        :rtype: str
        """
        return self._sort_code

    @sort_code.setter
    def sort_code(self, sort_code):
        """Sets the sort_code of this PaymentLine.

        The account sort code  # noqa: E501

        :param sort_code: The sort_code of this PaymentLine.  # noqa: E501
        :type: str
        """

        self._sort_code = sort_code

    @property
    def account_name(self):
        """Gets the account_name of this PaymentLine.  # noqa: E501

        The account name  # noqa: E501

        :return: The account_name of this PaymentLine.  # noqa: E501
        :rtype: str
        """
        return self._account_name

    @account_name.setter
    def account_name(self, account_name):
        """Sets the account_name of this PaymentLine.

        The account name  # noqa: E501

        :param account_name: The account_name of this PaymentLine.  # noqa: E501
        :type: str
        """

        self._account_name = account_name



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Contacts(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"contacts": "list[Contact]"}

    attribute_map = {"contacts": "Contacts"}

    def __init__(self, contacts=None):  # noqa: E501
        """Contacts - a model defined in OpenAPI"""  # noqa: E501

        self._contacts = None
        self.discriminator = None

        if contacts is not None:
            self.contacts = contacts

    @property
    def contacts(self):
        """Gets the contacts of this Contacts.  # noqa: E501


        :return: The contacts of this Contacts.  # noqa: E501
        :rtype: list[Contact]
        """
        return self._contacts

    @contacts.setter
    def contacts(self, contacts):
        """Sets the contacts of this Contacts.


        :param contacts: The contacts of this Contacts.  # noqa: E501
        :type: list[Contact]
        """

        self._contacts = contacts



# coding: utf-8

"""
    Xero Payroll UK

    This is the Xero Payroll API for orgs in the UK region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Employee(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "employee_id": "str",
        "title": "str",
        "first_name": "str",
        "last_name": "str",
        "date_of_birth": "date",
        "address": "Address",
        "email": "str",
        "gender": "str",
        "phone_number": "str",
        "start_date": "date",
        "end_date": "date",
        "payroll_calendar_id": "str",
        "updated_date_utc": "datetime",
        "created_date_utc": "datetime",
        "national_insurance_number": "str",
    }

    attribute_map = {
        "employee_id": "employeeID",
        "title": "title",
        "first_name": "firstName",
        "last_name": "lastName",
        "date_of_birth": "dateOfBirth",
        "address": "address",
        "email": "email",
        "gender": "gender",
        "phone_number": "phoneNumber",
        "start_date": "startDate",
        "end_date": "endDate",
        "payroll_calendar_id": "payrollCalendarID",
        "updated_date_utc": "updatedDateUTC",
        "created_date_utc": "createdDateUTC",
        "national_insurance_number": "nationalInsuranceNumber",
    }

    def __init__(
        self,
        employee_id=None,
        title=None,
        first_name=None,
        last_name=None,
        date_of_birth=None,
        address=None,
        email=None,
        gender=None,
        phone_number=None,
        start_date=None,
        end_date=None,
        payroll_calendar_id=None,
        updated_date_utc=None,
        created_date_utc=None,
        national_insurance_number=None,
    ):  # noqa: E501
        """Employee - a model defined in OpenAPI"""  # noqa: E501

        self._employee_id = None
        self._title = None
        self._first_name = None
        self._last_name = None
        self._date_of_birth = None
        self._address = None
        self._email = None
        self._gender = None
        self._phone_number = None
        self._start_date = None
        self._end_date = None
        self._payroll_calendar_id = None
        self._updated_date_utc = None
        self._created_date_utc = None
        self._national_insurance_number = None
        self.discriminator = None

        if employee_id is not None:
            self.employee_id = employee_id
        if title is not None:
            self.title = title
        if first_name is not None:
            self.first_name = first_name
        if last_name is not None:
            self.last_name = last_name
        if date_of_birth is not None:
            self.date_of_birth = date_of_birth
        if address is not None:
            self.address = address
        if email is not None:
            self.email = email
        if gender is not None:
            self.gender = gender
        if phone_number is not None:
            self.phone_number = phone_number
        if start_date is not None:
            self.start_date = start_date
        if end_date is not None:
            self.end_date = end_date
        if payroll_calendar_id is not None:
            self.payroll_calendar_id = payroll_calendar_id
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if created_date_utc is not None:
            self.created_date_utc = created_date_utc
        if national_insurance_number is not None:
            self.national_insurance_number = national_insurance_number

    @property
    def employee_id(self):
        """Gets the employee_id of this Employee.  # noqa: E501

        Xero unique identifier for the employee  # noqa: E501

        :return: The employee_id of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._employee_id

    @employee_id.setter
    def employee_id(self, employee_id):
        """Sets the employee_id of this Employee.

        Xero unique identifier for the employee  # noqa: E501

        :param employee_id: The employee_id of this Employee.  # noqa: E501
        :type: str
        """

        self._employee_id = employee_id

    @property
    def title(self):
        """Gets the title of this Employee.  # noqa: E501

        Title of the employee  # noqa: E501

        :return: The title of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Employee.

        Title of the employee  # noqa: E501

        :param title: The title of this Employee.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def first_name(self):
        """Gets the first_name of this Employee.  # noqa: E501

        First name of employee  # noqa: E501

        :return: The first_name of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """Sets the first_name of this Employee.

        First name of employee  # noqa: E501

        :param first_name: The first_name of this Employee.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def last_name(self):
        """Gets the last_name of this Employee.  # noqa: E501

        Last name of employee  # noqa: E501

        :return: The last_name of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """Sets the last_name of this Employee.

        Last name of employee  # noqa: E501

        :param last_name: The last_name of this Employee.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def date_of_birth(self):
        """Gets the date_of_birth of this Employee.  # noqa: E501

        Date of birth of the employee (YYYY-MM-DD)  # noqa: E501

        :return: The date_of_birth of this Employee.  # noqa: E501
        :rtype: date
        """
        return self._date_of_birth

    @date_of_birth.setter
    def date_of_birth(self, date_of_birth):
        """Sets the date_of_birth of this Employee.

        Date of birth of the employee (YYYY-MM-DD)  # noqa: E501

        :param date_of_birth: The date_of_birth of this Employee.  # noqa: E501
        :type: date
        """

        self._date_of_birth = date_of_birth

    @property
    def address(self):
        """Gets the address of this Employee.  # noqa: E501


        :return: The address of this Employee.  # noqa: E501
        :rtype: Address
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this Employee.


        :param address: The address of this Employee.  # noqa: E501
        :type: Address
        """

        self._address = address

    @property
    def email(self):
        """Gets the email of this Employee.  # noqa: E501

        The email address for the employee  # noqa: E501

        :return: The email of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this Employee.

        The email address for the employee  # noqa: E501

        :param email: The email of this Employee.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def gender(self):
        """Gets the gender of this Employee.  # noqa: E501

        The employee’s gender  # noqa: E501

        :return: The gender of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._gender

    @gender.setter
    def gender(self, gender):
        """Sets the gender of this Employee.

        The employee’s gender  # noqa: E501

        :param gender: The gender of this Employee.  # noqa: E501
        :type: str
        """
        allowed_values = ["M", "F", "None"]  # noqa: E501

        if gender:
            if gender not in allowed_values:
                raise ValueError(
                    "Invalid value for `gender` ({0}), must be one of {1}".format(  # noqa: E501
                        gender, allowed_values
                    )
                )

        self._gender = gender

    @property
    def phone_number(self):
        """Gets the phone_number of this Employee.  # noqa: E501

        Employee phone number  # noqa: E501

        :return: The phone_number of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this Employee.

        Employee phone number  # noqa: E501

        :param phone_number: The phone_number of this Employee.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def start_date(self):
        """Gets the start_date of this Employee.  # noqa: E501

        Employment start date of the employee at the time it was requested  # noqa: E501

        :return: The start_date of this Employee.  # noqa: E501
        :rtype: date
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this Employee.

        Employment start date of the employee at the time it was requested  # noqa: E501

        :param start_date: The start_date of this Employee.  # noqa: E501
        :type: date
        """

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this Employee.  # noqa: E501

        Employment end date of the employee at the time it was requested  # noqa: E501

        :return: The end_date of this Employee.  # noqa: E501
        :rtype: date
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this Employee.

        Employment end date of the employee at the time it was requested  # noqa: E501

        :param end_date: The end_date of this Employee.  # noqa: E501
        :type: date
        """

        self._end_date = end_date

    @property
    def payroll_calendar_id(self):
        """Gets the payroll_calendar_id of this Employee.  # noqa: E501

        Xero unique identifier for the payroll calendar of the employee  # noqa: E501

        :return: The payroll_calendar_id of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._payroll_calendar_id

    @payroll_calendar_id.setter
    def payroll_calendar_id(self, payroll_calendar_id):
        """Sets the payroll_calendar_id of this Employee.

        Xero unique identifier for the payroll calendar of the employee  # noqa: E501

        :param payroll_calendar_id: The payroll_calendar_id of this Employee.  # noqa: E501
        :type: str
        """

        self._payroll_calendar_id = payroll_calendar_id

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this Employee.  # noqa: E501

        UTC timestamp of last update to the employee  # noqa: E501

        :return: The updated_date_utc of this Employee.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this Employee.

        UTC timestamp of last update to the employee  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this Employee.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def created_date_utc(self):
        """Gets the created_date_utc of this Employee.  # noqa: E501

        UTC timestamp when the employee was created in Xero  # noqa: E501

        :return: The created_date_utc of this Employee.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date_utc

    @created_date_utc.setter
    def created_date_utc(self, created_date_utc):
        """Sets the created_date_utc of this Employee.

        UTC timestamp when the employee was created in Xero  # noqa: E501

        :param created_date_utc: The created_date_utc of this Employee.  # noqa: E501
        :type: datetime
        """

        self._created_date_utc = created_date_utc

    @property
    def national_insurance_number(self):
        """Gets the national_insurance_number of this Employee.  # noqa: E501

        National insurance number of the employee  # noqa: E501

        :return: The national_insurance_number of this Employee.  # noqa: E501
        :rtype: str
        """
        return self._national_insurance_number

    @national_insurance_number.setter
    def national_insurance_number(self, national_insurance_number):
        """Sets the national_insurance_number of this Employee.

        National insurance number of the employee  # noqa: E501

        :param national_insurance_number: The national_insurance_number of this Employee.  # noqa: E501
        :type: str
        """

        self._national_insurance_number = national_insurance_number



# coding: utf-8

"""
    Xero OAuth 2 Identity Service API

    These endpoints are related to managing authentication tokens and identity for Xero API  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Connection(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "id": "str",
        "tenant_id": "str",
        "auth_event_id": "str",
        "tenant_type": "str",
        "tenant_name": "str",
        "created_date_utc": "datetime",
        "updated_date_utc": "datetime",
    }

    attribute_map = {
        "id": "id",
        "tenant_id": "tenantId",
        "auth_event_id": "authEventId",
        "tenant_type": "tenantType",
        "tenant_name": "tenantName",
        "created_date_utc": "createdDateUtc",
        "updated_date_utc": "updatedDateUtc",
    }

    def __init__(
        self,
        id=None,
        tenant_id=None,
        auth_event_id=None,
        tenant_type=None,
        tenant_name=None,
        created_date_utc=None,
        updated_date_utc=None,
    ):  # noqa: E501
        """Connection - a model defined in OpenAPI"""  # noqa: E501

        self._id = None
        self._tenant_id = None
        self._auth_event_id = None
        self._tenant_type = None
        self._tenant_name = None
        self._created_date_utc = None
        self._updated_date_utc = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if auth_event_id is not None:
            self.auth_event_id = auth_event_id
        if tenant_type is not None:
            self.tenant_type = tenant_type
        if tenant_name is not None:
            self.tenant_name = tenant_name
        if created_date_utc is not None:
            self.created_date_utc = created_date_utc
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc

    @property
    def id(self):
        """Gets the id of this Connection.  # noqa: E501

        Xero identifier  # noqa: E501

        :return: The id of this Connection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Connection.

        Xero identifier  # noqa: E501

        :param id: The id of this Connection.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def tenant_id(self):
        """Gets the tenant_id of this Connection.  # noqa: E501

        Xero identifier of organisation  # noqa: E501

        :return: The tenant_id of this Connection.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this Connection.

        Xero identifier of organisation  # noqa: E501

        :param tenant_id: The tenant_id of this Connection.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def auth_event_id(self):
        """Gets the auth_event_id of this Connection.  # noqa: E501

        Identifier shared across connections authorised at the same time  # noqa: E501

        :return: The auth_event_id of this Connection.  # noqa: E501
        :rtype: str
        """
        return self._auth_event_id

    @auth_event_id.setter
    def auth_event_id(self, auth_event_id):
        """Sets the auth_event_id of this Connection.

        Identifier shared across connections authorised at the same time  # noqa: E501

        :param auth_event_id: The auth_event_id of this Connection.  # noqa: E501
        :type: str
        """

        self._auth_event_id = auth_event_id

    @property
    def tenant_type(self):
        """Gets the tenant_type of this Connection.  # noqa: E501

        Xero tenant type (i.e. ORGANISATION, PRACTICE)  # noqa: E501

        :return: The tenant_type of this Connection.  # noqa: E501
        :rtype: str
        """
        return self._tenant_type

    @tenant_type.setter
    def tenant_type(self, tenant_type):
        """Sets the tenant_type of this Connection.

        Xero tenant type (i.e. ORGANISATION, PRACTICE)  # noqa: E501

        :param tenant_type: The tenant_type of this Connection.  # noqa: E501
        :type: str
        """

        self._tenant_type = tenant_type

    @property
    def tenant_name(self):
        """Gets the tenant_name of this Connection.  # noqa: E501

        Xero tenant name  # noqa: E501

        :return: The tenant_name of this Connection.  # noqa: E501
        :rtype: str
        """
        return self._tenant_name

    @tenant_name.setter
    def tenant_name(self, tenant_name):
        """Sets the tenant_name of this Connection.

        Xero tenant name  # noqa: E501

        :param tenant_name: The tenant_name of this Connection.  # noqa: E501
        :type: str
        """

        self._tenant_name = tenant_name

    @property
    def created_date_utc(self):
        """Gets the created_date_utc of this Connection.  # noqa: E501

        The date when the user connected this tenant to your app  # noqa: E501

        :return: The created_date_utc of this Connection.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date_utc

    @created_date_utc.setter
    def created_date_utc(self, created_date_utc):
        """Sets the created_date_utc of this Connection.

        The date when the user connected this tenant to your app  # noqa: E501

        :param created_date_utc: The created_date_utc of this Connection.  # noqa: E501
        :type: datetime
        """

        self._created_date_utc = created_date_utc

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this Connection.  # noqa: E501

        The date when the user most recently connected this tenant to your app. May differ to the created date if the user has disconnected and subsequently reconnected this tenant to your app.  # noqa: E501

        :return: The updated_date_utc of this Connection.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this Connection.

        The date when the user most recently connected this tenant to your app. May differ to the created date if the user has disconnected and subsequently reconnected this tenant to your app.  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this Connection.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Payment(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "invoice": "Invoice",
        "credit_note": "CreditNote",
        "prepayment": "Prepayment",
        "overpayment": "Overpayment",
        "invoice_number": "str",
        "credit_note_number": "str",
        "account": "Account",
        "code": "str",
        "date": "date[ms-format]",
        "currency_rate": "float",
        "amount": "float",
        "reference": "str",
        "is_reconciled": "bool",
        "status": "str",
        "payment_type": "str",
        "updated_date_utc": "datetime[ms-format]",
        "payment_id": "str",
        "batch_payment_id": "str",
        "bank_account_number": "str",
        "particulars": "str",
        "details": "str",
        "has_account": "bool",
        "has_validation_errors": "bool",
        "status_attribute_string": "str",
        "validation_errors": "list[ValidationError]",
    }

    attribute_map = {
        "invoice": "Invoice",
        "credit_note": "CreditNote",
        "prepayment": "Prepayment",
        "overpayment": "Overpayment",
        "invoice_number": "InvoiceNumber",
        "credit_note_number": "CreditNoteNumber",
        "account": "Account",
        "code": "Code",
        "date": "Date",
        "currency_rate": "CurrencyRate",
        "amount": "Amount",
        "reference": "Reference",
        "is_reconciled": "IsReconciled",
        "status": "Status",
        "payment_type": "PaymentType",
        "updated_date_utc": "UpdatedDateUTC",
        "payment_id": "PaymentID",
        "batch_payment_id": "BatchPaymentID",
        "bank_account_number": "BankAccountNumber",
        "particulars": "Particulars",
        "details": "Details",
        "has_account": "HasAccount",
        "has_validation_errors": "HasValidationErrors",
        "status_attribute_string": "StatusAttributeString",
        "validation_errors": "ValidationErrors",
    }

    def __init__(
        self,
        invoice=None,
        credit_note=None,
        prepayment=None,
        overpayment=None,
        invoice_number=None,
        credit_note_number=None,
        account=None,
        code=None,
        date=None,
        currency_rate=None,
        amount=None,
        reference=None,
        is_reconciled=None,
        status=None,
        payment_type=None,
        updated_date_utc=None,
        payment_id=None,
        batch_payment_id=None,
        bank_account_number=None,
        particulars=None,
        details=None,
        has_account=False,
        has_validation_errors=False,
        status_attribute_string=None,
        validation_errors=None,
    ):  # noqa: E501
        """Payment - a model defined in OpenAPI"""  # noqa: E501

        self._invoice = None
        self._credit_note = None
        self._prepayment = None
        self._overpayment = None
        self._invoice_number = None
        self._credit_note_number = None
        self._account = None
        self._code = None
        self._date = None
        self._currency_rate = None
        self._amount = None
        self._reference = None
        self._is_reconciled = None
        self._status = None
        self._payment_type = None
        self._updated_date_utc = None
        self._payment_id = None
        self._batch_payment_id = None
        self._bank_account_number = None
        self._particulars = None
        self._details = None
        self._has_account = None
        self._has_validation_errors = None
        self._status_attribute_string = None
        self._validation_errors = None
        self.discriminator = None

        if invoice is not None:
            self.invoice = invoice
        if credit_note is not None:
            self.credit_note = credit_note
        if prepayment is not None:
            self.prepayment = prepayment
        if overpayment is not None:
            self.overpayment = overpayment
        if invoice_number is not None:
            self.invoice_number = invoice_number
        if credit_note_number is not None:
            self.credit_note_number = credit_note_number
        if account is not None:
            self.account = account
        if code is not None:
            self.code = code
        if date is not None:
            self.date = date
        if currency_rate is not None:
            self.currency_rate = currency_rate
        if amount is not None:
            self.amount = amount
        if reference is not None:
            self.reference = reference
        if is_reconciled is not None:
            self.is_reconciled = is_reconciled
        if status is not None:
            self.status = status
        if payment_type is not None:
            self.payment_type = payment_type
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if payment_id is not None:
            self.payment_id = payment_id
        if batch_payment_id is not None:
            self.batch_payment_id = batch_payment_id
        if bank_account_number is not None:
            self.bank_account_number = bank_account_number
        if particulars is not None:
            self.particulars = particulars
        if details is not None:
            self.details = details
        if has_account is not None:
            self.has_account = has_account
        if has_validation_errors is not None:
            self.has_validation_errors = has_validation_errors
        if status_attribute_string is not None:
            self.status_attribute_string = status_attribute_string
        if validation_errors is not None:
            self.validation_errors = validation_errors

    @property
    def invoice(self):
        """Gets the invoice of this Payment.  # noqa: E501


        :return: The invoice of this Payment.  # noqa: E501
        :rtype: Invoice
        """
        return self._invoice

    @invoice.setter
    def invoice(self, invoice):
        """Sets the invoice of this Payment.


        :param invoice: The invoice of this Payment.  # noqa: E501
        :type: Invoice
        """

        self._invoice = invoice

    @property
    def credit_note(self):
        """Gets the credit_note of this Payment.  # noqa: E501


        :return: The credit_note of this Payment.  # noqa: E501
        :rtype: CreditNote
        """
        return self._credit_note

    @credit_note.setter
    def credit_note(self, credit_note):
        """Sets the credit_note of this Payment.


        :param credit_note: The credit_note of this Payment.  # noqa: E501
        :type: CreditNote
        """

        self._credit_note = credit_note

    @property
    def prepayment(self):
        """Gets the prepayment of this Payment.  # noqa: E501


        :return: The prepayment of this Payment.  # noqa: E501
        :rtype: Prepayment
        """
        return self._prepayment

    @prepayment.setter
    def prepayment(self, prepayment):
        """Sets the prepayment of this Payment.


        :param prepayment: The prepayment of this Payment.  # noqa: E501
        :type: Prepayment
        """

        self._prepayment = prepayment

    @property
    def overpayment(self):
        """Gets the overpayment of this Payment.  # noqa: E501


        :return: The overpayment of this Payment.  # noqa: E501
        :rtype: Overpayment
        """
        return self._overpayment

    @overpayment.setter
    def overpayment(self, overpayment):
        """Sets the overpayment of this Payment.


        :param overpayment: The overpayment of this Payment.  # noqa: E501
        :type: Overpayment
        """

        self._overpayment = overpayment

    @property
    def invoice_number(self):
        """Gets the invoice_number of this Payment.  # noqa: E501

        Number of invoice or credit note you are applying payment to e.g.INV-4003  # noqa: E501

        :return: The invoice_number of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._invoice_number

    @invoice_number.setter
    def invoice_number(self, invoice_number):
        """Sets the invoice_number of this Payment.

        Number of invoice or credit note you are applying payment to e.g.INV-4003  # noqa: E501

        :param invoice_number: The invoice_number of this Payment.  # noqa: E501
        :type: str
        """

        self._invoice_number = invoice_number

    @property
    def credit_note_number(self):
        """Gets the credit_note_number of this Payment.  # noqa: E501

        Number of invoice or credit note you are applying payment to e.g. INV-4003  # noqa: E501

        :return: The credit_note_number of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._credit_note_number

    @credit_note_number.setter
    def credit_note_number(self, credit_note_number):
        """Sets the credit_note_number of this Payment.

        Number of invoice or credit note you are applying payment to e.g. INV-4003  # noqa: E501

        :param credit_note_number: The credit_note_number of this Payment.  # noqa: E501
        :type: str
        """

        self._credit_note_number = credit_note_number

    @property
    def account(self):
        """Gets the account of this Payment.  # noqa: E501


        :return: The account of this Payment.  # noqa: E501
        :rtype: Account
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this Payment.


        :param account: The account of this Payment.  # noqa: E501
        :type: Account
        """

        self._account = account

    @property
    def code(self):
        """Gets the code of this Payment.  # noqa: E501

        Code of account you are using to make the payment e.g. 001 (note- not all accounts have a code value)  # noqa: E501

        :return: The code of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this Payment.

        Code of account you are using to make the payment e.g. 001 (note- not all accounts have a code value)  # noqa: E501

        :param code: The code of this Payment.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def date(self):
        """Gets the date of this Payment.  # noqa: E501

        Date the payment is being made (YYYY-MM-DD) e.g. 2009-09-06  # noqa: E501

        :return: The date of this Payment.  # noqa: E501
        :rtype: date
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this Payment.

        Date the payment is being made (YYYY-MM-DD) e.g. 2009-09-06  # noqa: E501

        :param date: The date of this Payment.  # noqa: E501
        :type: date
        """

        self._date = date

    @property
    def currency_rate(self):
        """Gets the currency_rate of this Payment.  # noqa: E501

        Exchange rate when payment is received. Only used for non base currency invoices and credit notes e.g. 0.7500  # noqa: E501

        :return: The currency_rate of this Payment.  # noqa: E501
        :rtype: float
        """
        return self._currency_rate

    @currency_rate.setter
    def currency_rate(self, currency_rate):
        """Sets the currency_rate of this Payment.

        Exchange rate when payment is received. Only used for non base currency invoices and credit notes e.g. 0.7500  # noqa: E501

        :param currency_rate: The currency_rate of this Payment.  # noqa: E501
        :type: float
        """

        self._currency_rate = currency_rate

    @property
    def amount(self):
        """Gets the amount of this Payment.  # noqa: E501

        The amount of the payment. Must be less than or equal to the outstanding amount owing on the invoice e.g. 200.00  # noqa: E501

        :return: The amount of this Payment.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Payment.

        The amount of the payment. Must be less than or equal to the outstanding amount owing on the invoice e.g. 200.00  # noqa: E501

        :param amount: The amount of this Payment.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def reference(self):
        """Gets the reference of this Payment.  # noqa: E501

        An optional description for the payment e.g. Direct Debit  # noqa: E501

        :return: The reference of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._reference

    @reference.setter
    def reference(self, reference):
        """Sets the reference of this Payment.

        An optional description for the payment e.g. Direct Debit  # noqa: E501

        :param reference: The reference of this Payment.  # noqa: E501
        :type: str
        """

        self._reference = reference

    @property
    def is_reconciled(self):
        """Gets the is_reconciled of this Payment.  # noqa: E501

        An optional parameter for the payment. A boolean indicating whether you would like the payment to be created as reconciled when using PUT, or whether a payment has been reconciled when using GET  # noqa: E501

        :return: The is_reconciled of this Payment.  # noqa: E501
        :rtype: bool
        """
        return self._is_reconciled

    @is_reconciled.setter
    def is_reconciled(self, is_reconciled):
        """Sets the is_reconciled of this Payment.

        An optional parameter for the payment. A boolean indicating whether you would like the payment to be created as reconciled when using PUT, or whether a payment has been reconciled when using GET  # noqa: E501

        :param is_reconciled: The is_reconciled of this Payment.  # noqa: E501
        :type: bool
        """

        self._is_reconciled = is_reconciled

    @property
    def status(self):
        """Gets the status of this Payment.  # noqa: E501

        The status of the payment.  # noqa: E501

        :return: The status of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this Payment.

        The status of the payment.  # noqa: E501

        :param status: The status of this Payment.  # noqa: E501
        :type: str
        """
        allowed_values = ["AUTHORISED", "DELETED", "None"]  # noqa: E501

        if status:
            if status not in allowed_values:
                raise ValueError(
                    "Invalid value for `status` ({0}), must be one of {1}".format(  # noqa: E501
                        status, allowed_values
                    )
                )

        self._status = status

    @property
    def payment_type(self):
        """Gets the payment_type of this Payment.  # noqa: E501

        See Payment Types.  # noqa: E501

        :return: The payment_type of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._payment_type

    @payment_type.setter
    def payment_type(self, payment_type):
        """Sets the payment_type of this Payment.

        See Payment Types.  # noqa: E501

        :param payment_type: The payment_type of this Payment.  # noqa: E501
        :type: str
        """
        allowed_values = [
            "ACCRECPAYMENT",
            "ACCPAYPAYMENT",
            "ARCREDITPAYMENT",
            "APCREDITPAYMENT",
            "AROVERPAYMENTPAYMENT",
            "ARPREPAYMENTPAYMENT",
            "APPREPAYMENTPAYMENT",
            "APOVERPAYMENTPAYMENT",
            "None",
        ]  # noqa: E501

        if payment_type:
            if payment_type not in allowed_values:
                raise ValueError(
                    "Invalid value for `payment_type` ({0}), must be one of {1}".format(  # noqa: E501
                        payment_type, allowed_values
                    )
                )

        self._payment_type = payment_type

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this Payment.  # noqa: E501

        UTC timestamp of last update to the payment  # noqa: E501

        :return: The updated_date_utc of this Payment.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this Payment.

        UTC timestamp of last update to the payment  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this Payment.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def payment_id(self):
        """Gets the payment_id of this Payment.  # noqa: E501

        The Xero identifier for an Payment e.g. 297c2dc5-cc47-4afd-8ec8-74990b8761e9  # noqa: E501

        :return: The payment_id of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._payment_id

    @payment_id.setter
    def payment_id(self, payment_id):
        """Sets the payment_id of this Payment.

        The Xero identifier for an Payment e.g. 297c2dc5-cc47-4afd-8ec8-74990b8761e9  # noqa: E501

        :param payment_id: The payment_id of this Payment.  # noqa: E501
        :type: str
        """

        self._payment_id = payment_id

    @property
    def batch_payment_id(self):
        """Gets the batch_payment_id of this Payment.  # noqa: E501

        Present if the payment was created as part of a batch.  # noqa: E501

        :return: The batch_payment_id of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._batch_payment_id

    @batch_payment_id.setter
    def batch_payment_id(self, batch_payment_id):
        """Sets the batch_payment_id of this Payment.

        Present if the payment was created as part of a batch.  # noqa: E501

        :param batch_payment_id: The batch_payment_id of this Payment.  # noqa: E501
        :type: str
        """

        self._batch_payment_id = batch_payment_id

    @property
    def bank_account_number(self):
        """Gets the bank_account_number of this Payment.  # noqa: E501

        The suppliers bank account number the payment is being made to  # noqa: E501

        :return: The bank_account_number of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._bank_account_number

    @bank_account_number.setter
    def bank_account_number(self, bank_account_number):
        """Sets the bank_account_number of this Payment.

        The suppliers bank account number the payment is being made to  # noqa: E501

        :param bank_account_number: The bank_account_number of this Payment.  # noqa: E501
        :type: str
        """

        self._bank_account_number = bank_account_number

    @property
    def particulars(self):
        """Gets the particulars of this Payment.  # noqa: E501

        The suppliers bank account number the payment is being made to  # noqa: E501

        :return: The particulars of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._particulars

    @particulars.setter
    def particulars(self, particulars):
        """Sets the particulars of this Payment.

        The suppliers bank account number the payment is being made to  # noqa: E501

        :param particulars: The particulars of this Payment.  # noqa: E501
        :type: str
        """

        self._particulars = particulars

    @property
    def details(self):
        """Gets the details of this Payment.  # noqa: E501

        The information to appear on the supplier's bank account  # noqa: E501

        :return: The details of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this Payment.

        The information to appear on the supplier's bank account  # noqa: E501

        :param details: The details of this Payment.  # noqa: E501
        :type: str
        """

        self._details = details

    @property
    def has_account(self):
        """Gets the has_account of this Payment.  # noqa: E501

        A boolean to indicate if a contact has an validation errors  # noqa: E501

        :return: The has_account of this Payment.  # noqa: E501
        :rtype: bool
        """
        return self._has_account

    @has_account.setter
    def has_account(self, has_account):
        """Sets the has_account of this Payment.

        A boolean to indicate if a contact has an validation errors  # noqa: E501

        :param has_account: The has_account of this Payment.  # noqa: E501
        :type: bool
        """

        self._has_account = has_account

    @property
    def has_validation_errors(self):
        """Gets the has_validation_errors of this Payment.  # noqa: E501

        A boolean to indicate if a contact has an validation errors  # noqa: E501

        :return: The has_validation_errors of this Payment.  # noqa: E501
        :rtype: bool
        """
        return self._has_validation_errors

    @has_validation_errors.setter
    def has_validation_errors(self, has_validation_errors):
        """Sets the has_validation_errors of this Payment.

        A boolean to indicate if a contact has an validation errors  # noqa: E501

        :param has_validation_errors: The has_validation_errors of this Payment.  # noqa: E501
        :type: bool
        """

        self._has_validation_errors = has_validation_errors

    @property
    def status_attribute_string(self):
        """Gets the status_attribute_string of this Payment.  # noqa: E501

        A string to indicate if a invoice status  # noqa: E501

        :return: The status_attribute_string of this Payment.  # noqa: E501
        :rtype: str
        """
        return self._status_attribute_string

    @status_attribute_string.setter
    def status_attribute_string(self, status_attribute_string):
        """Sets the status_attribute_string of this Payment.

        A string to indicate if a invoice status  # noqa: E501

        :param status_attribute_string: The status_attribute_string of this Payment.  # noqa: E501
        :type: str
        """

        self._status_attribute_string = status_attribute_string

    @property
    def validation_errors(self):
        """Gets the validation_errors of this Payment.  # noqa: E501

        Displays array of validation error messages from the API  # noqa: E501

        :return: The validation_errors of this Payment.  # noqa: E501
        :rtype: list[ValidationError]
        """
        return self._validation_errors

    @validation_errors.setter
    def validation_errors(self, validation_errors):
        """Sets the validation_errors of this Payment.

        Displays array of validation error messages from the API  # noqa: E501

        :param validation_errors: The validation_errors of this Payment.  # noqa: E501
        :type: list[ValidationError]
        """

        self._validation_errors = validation_errors



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class HistoryRecord(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "details": "str",
        "changes": "str",
        "user": "str",
        "date_utc": "datetime[ms-format]",
    }

    attribute_map = {
        "details": "Details",
        "changes": "Changes",
        "user": "User",
        "date_utc": "DateUTC",
    }

    def __init__(
        self, details=None, changes=None, user=None, date_utc=None
    ):  # noqa: E501
        """HistoryRecord - a model defined in OpenAPI"""  # noqa: E501

        self._details = None
        self._changes = None
        self._user = None
        self._date_utc = None
        self.discriminator = None

        if details is not None:
            self.details = details
        if changes is not None:
            self.changes = changes
        if user is not None:
            self.user = user
        if date_utc is not None:
            self.date_utc = date_utc

    @property
    def details(self):
        """Gets the details of this HistoryRecord.  # noqa: E501

        details  # noqa: E501

        :return: The details of this HistoryRecord.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this HistoryRecord.

        details  # noqa: E501

        :param details: The details of this HistoryRecord.  # noqa: E501
        :type: str
        """

        self._details = details

    @property
    def changes(self):
        """Gets the changes of this HistoryRecord.  # noqa: E501

        Name of branding theme  # noqa: E501

        :return: The changes of this HistoryRecord.  # noqa: E501
        :rtype: str
        """
        return self._changes

    @changes.setter
    def changes(self, changes):
        """Sets the changes of this HistoryRecord.

        Name of branding theme  # noqa: E501

        :param changes: The changes of this HistoryRecord.  # noqa: E501
        :type: str
        """

        self._changes = changes

    @property
    def user(self):
        """Gets the user of this HistoryRecord.  # noqa: E501

        has a value of 0  # noqa: E501

        :return: The user of this HistoryRecord.  # noqa: E501
        :rtype: str
        """
        return self._user

    @user.setter
    def user(self, user):
        """Sets the user of this HistoryRecord.

        has a value of 0  # noqa: E501

        :param user: The user of this HistoryRecord.  # noqa: E501
        :type: str
        """

        self._user = user

    @property
    def date_utc(self):
        """Gets the date_utc of this HistoryRecord.  # noqa: E501

        UTC timestamp of creation date of branding theme  # noqa: E501

        :return: The date_utc of this HistoryRecord.  # noqa: E501
        :rtype: datetime
        """
        return self._date_utc

    @date_utc.setter
    def date_utc(self, date_utc):
        """Sets the date_utc of this HistoryRecord.

        UTC timestamp of creation date of branding theme  # noqa: E501

        :param date_utc: The date_utc of this HistoryRecord.  # noqa: E501
        :type: datetime
        """

        self._date_utc = date_utc



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class PaymentTerm(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"bills": "Bill", "sales": "Bill"}

    attribute_map = {"bills": "Bills", "sales": "Sales"}

    def __init__(self, bills=None, sales=None):  # noqa: E501
        """PaymentTerm - a model defined in OpenAPI"""  # noqa: E501

        self._bills = None
        self._sales = None
        self.discriminator = None

        if bills is not None:
            self.bills = bills
        if sales is not None:
            self.sales = sales

    @property
    def bills(self):
        """Gets the bills of this PaymentTerm.  # noqa: E501


        :return: The bills of this PaymentTerm.  # noqa: E501
        :rtype: Bill
        """
        return self._bills

    @bills.setter
    def bills(self, bills):
        """Sets the bills of this PaymentTerm.


        :param bills: The bills of this PaymentTerm.  # noqa: E501
        :type: Bill
        """

        self._bills = bills

    @property
    def sales(self):
        """Gets the sales of this PaymentTerm.  # noqa: E501


        :return: The sales of this PaymentTerm.  # noqa: E501
        :rtype: Bill
        """
        return self._sales

    @sales.setter
    def sales(self, sales):
        """Sets the sales of this PaymentTerm.


        :param sales: The sales of this PaymentTerm.  # noqa: E501
        :type: Bill
        """

        self._sales = sales



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class EarningsRate(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "name": "str",
        "account_code": "str",
        "type_of_units": "str",
        "is_exempt_from_tax": "bool",
        "is_exempt_from_super": "bool",
        "is_reportable_as_w1": "bool",
        "earnings_type": "EarningsType",
        "earnings_rate_id": "str",
        "rate_type": "RateType",
        "rate_per_unit": "str",
        "multiplier": "float",
        "accrue_leave": "bool",
        "amount": "float",
        "employment_termination_payment_type": "EmploymentTerminationPaymentType",
        "updated_date_utc": "datetime[ms-format]",
        "current_record": "bool",
        "allowance_type": "AllowanceType",
    }

    attribute_map = {
        "name": "Name",
        "account_code": "AccountCode",
        "type_of_units": "TypeOfUnits",
        "is_exempt_from_tax": "IsExemptFromTax",
        "is_exempt_from_super": "IsExemptFromSuper",
        "is_reportable_as_w1": "IsReportableAsW1",
        "earnings_type": "EarningsType",
        "earnings_rate_id": "EarningsRateID",
        "rate_type": "RateType",
        "rate_per_unit": "RatePerUnit",
        "multiplier": "Multiplier",
        "accrue_leave": "AccrueLeave",
        "amount": "Amount",
        "employment_termination_payment_type": "EmploymentTerminationPaymentType",
        "updated_date_utc": "UpdatedDateUTC",
        "current_record": "CurrentRecord",
        "allowance_type": "AllowanceType",
    }

    def __init__(
        self,
        name=None,
        account_code=None,
        type_of_units=None,
        is_exempt_from_tax=None,
        is_exempt_from_super=None,
        is_reportable_as_w1=None,
        earnings_type=None,
        earnings_rate_id=None,
        rate_type=None,
        rate_per_unit=None,
        multiplier=None,
        accrue_leave=None,
        amount=None,
        employment_termination_payment_type=None,
        updated_date_utc=None,
        current_record=None,
        allowance_type=None,
    ):  # noqa: E501
        """EarningsRate - a model defined in OpenAPI"""  # noqa: E501

        self._name = None
        self._account_code = None
        self._type_of_units = None
        self._is_exempt_from_tax = None
        self._is_exempt_from_super = None
        self._is_reportable_as_w1 = None
        self._earnings_type = None
        self._earnings_rate_id = None
        self._rate_type = None
        self._rate_per_unit = None
        self._multiplier = None
        self._accrue_leave = None
        self._amount = None
        self._employment_termination_payment_type = None
        self._updated_date_utc = None
        self._current_record = None
        self._allowance_type = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if account_code is not None:
            self.account_code = account_code
        if type_of_units is not None:
            self.type_of_units = type_of_units
        if is_exempt_from_tax is not None:
            self.is_exempt_from_tax = is_exempt_from_tax
        if is_exempt_from_super is not None:
            self.is_exempt_from_super = is_exempt_from_super
        if is_reportable_as_w1 is not None:
            self.is_reportable_as_w1 = is_reportable_as_w1
        if earnings_type is not None:
            self.earnings_type = earnings_type
        if earnings_rate_id is not None:
            self.earnings_rate_id = earnings_rate_id
        if rate_type is not None:
            self.rate_type = rate_type
        if rate_per_unit is not None:
            self.rate_per_unit = rate_per_unit
        if multiplier is not None:
            self.multiplier = multiplier
        if accrue_leave is not None:
            self.accrue_leave = accrue_leave
        if amount is not None:
            self.amount = amount
        if employment_termination_payment_type is not None:
            self.employment_termination_payment_type = (
                employment_termination_payment_type
            )
        if updated_date_utc is not None:
            self.updated_date_utc = updated_date_utc
        if current_record is not None:
            self.current_record = current_record
        if allowance_type is not None:
            self.allowance_type = allowance_type

    @property
    def name(self):
        """Gets the name of this EarningsRate.  # noqa: E501

        Name of the earnings rate (max length = 100)  # noqa: E501

        :return: The name of this EarningsRate.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this EarningsRate.

        Name of the earnings rate (max length = 100)  # noqa: E501

        :param name: The name of this EarningsRate.  # noqa: E501
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError(
                "Invalid value for `name`, "
                "length must be less than or equal to `100`"
            )  # noqa: E501

        self._name = name

    @property
    def account_code(self):
        """Gets the account_code of this EarningsRate.  # noqa: E501

        See Accounts  # noqa: E501

        :return: The account_code of this EarningsRate.  # noqa: E501
        :rtype: str
        """
        return self._account_code

    @account_code.setter
    def account_code(self, account_code):
        """Sets the account_code of this EarningsRate.

        See Accounts  # noqa: E501

        :param account_code: The account_code of this EarningsRate.  # noqa: E501
        :type: str
        """

        self._account_code = account_code

    @property
    def type_of_units(self):
        """Gets the type_of_units of this EarningsRate.  # noqa: E501

        Type of units used to record earnings (max length = 50). Only When RateType is RATEPERUNIT  # noqa: E501

        :return: The type_of_units of this EarningsRate.  # noqa: E501
        :rtype: str
        """
        return self._type_of_units

    @type_of_units.setter
    def type_of_units(self, type_of_units):
        """Sets the type_of_units of this EarningsRate.

        Type of units used to record earnings (max length = 50). Only When RateType is RATEPERUNIT  # noqa: E501

        :param type_of_units: The type_of_units of this EarningsRate.  # noqa: E501
        :type: str
        """
        if type_of_units is not None and len(type_of_units) > 50:
            raise ValueError(
                "Invalid value for `type_of_units`, "
                "length must be less than or equal to `50`"
            )  # noqa: E501

        self._type_of_units = type_of_units

    @property
    def is_exempt_from_tax(self):
        """Gets the is_exempt_from_tax of this EarningsRate.  # noqa: E501

        Most payments are subject to tax, so you should only set this value if you are sure that a payment is exempt from PAYG withholding  # noqa: E501

        :return: The is_exempt_from_tax of this EarningsRate.  # noqa: E501
        :rtype: bool
        """
        return self._is_exempt_from_tax

    @is_exempt_from_tax.setter
    def is_exempt_from_tax(self, is_exempt_from_tax):
        """Sets the is_exempt_from_tax of this EarningsRate.

        Most payments are subject to tax, so you should only set this value if you are sure that a payment is exempt from PAYG withholding  # noqa: E501

        :param is_exempt_from_tax: The is_exempt_from_tax of this EarningsRate.  # noqa: E501
        :type: bool
        """

        self._is_exempt_from_tax = is_exempt_from_tax

    @property
    def is_exempt_from_super(self):
        """Gets the is_exempt_from_super of this EarningsRate.  # noqa: E501

        See the ATO website for details of which payments are exempt from SGC  # noqa: E501

        :return: The is_exempt_from_super of this EarningsRate.  # noqa: E501
        :rtype: bool
        """
        return self._is_exempt_from_super

    @is_exempt_from_super.setter
    def is_exempt_from_super(self, is_exempt_from_super):
        """Sets the is_exempt_from_super of this EarningsRate.

        See the ATO website for details of which payments are exempt from SGC  # noqa: E501

        :param is_exempt_from_super: The is_exempt_from_super of this EarningsRate.  # noqa: E501
        :type: bool
        """

        self._is_exempt_from_super = is_exempt_from_super

    @property
    def is_reportable_as_w1(self):
        """Gets the is_reportable_as_w1 of this EarningsRate.  # noqa: E501

        Boolean to determine if the earnings rate is reportable or exempt from W1  # noqa: E501

        :return: The is_reportable_as_w1 of this EarningsRate.  # noqa: E501
        :rtype: bool
        """
        return self._is_reportable_as_w1

    @is_reportable_as_w1.setter
    def is_reportable_as_w1(self, is_reportable_as_w1):
        """Sets the is_reportable_as_w1 of this EarningsRate.

        Boolean to determine if the earnings rate is reportable or exempt from W1  # noqa: E501

        :param is_reportable_as_w1: The is_reportable_as_w1 of this EarningsRate.  # noqa: E501
        :type: bool
        """

        self._is_reportable_as_w1 = is_reportable_as_w1

    @property
    def earnings_type(self):
        """Gets the earnings_type of this EarningsRate.  # noqa: E501


        :return: The earnings_type of this EarningsRate.  # noqa: E501
        :rtype: EarningsType
        """
        return self._earnings_type

    @earnings_type.setter
    def earnings_type(self, earnings_type):
        """Sets the earnings_type of this EarningsRate.


        :param earnings_type: The earnings_type of this EarningsRate.  # noqa: E501
        :type: EarningsType
        """

        self._earnings_type = earnings_type

    @property
    def earnings_rate_id(self):
        """Gets the earnings_rate_id of this EarningsRate.  # noqa: E501

        Xero identifier  # noqa: E501

        :return: The earnings_rate_id of this EarningsRate.  # noqa: E501
        :rtype: str
        """
        return self._earnings_rate_id

    @earnings_rate_id.setter
    def earnings_rate_id(self, earnings_rate_id):
        """Sets the earnings_rate_id of this EarningsRate.

        Xero identifier  # noqa: E501

        :param earnings_rate_id: The earnings_rate_id of this EarningsRate.  # noqa: E501
        :type: str
        """

        self._earnings_rate_id = earnings_rate_id

    @property
    def rate_type(self):
        """Gets the rate_type of this EarningsRate.  # noqa: E501


        :return: The rate_type of this EarningsRate.  # noqa: E501
        :rtype: RateType
        """
        return self._rate_type

    @rate_type.setter
    def rate_type(self, rate_type):
        """Sets the rate_type of this EarningsRate.


        :param rate_type: The rate_type of this EarningsRate.  # noqa: E501
        :type: RateType
        """

        self._rate_type = rate_type

    @property
    def rate_per_unit(self):
        """Gets the rate_per_unit of this EarningsRate.  # noqa: E501

        Default rate per unit (optional). Only applicable if RateType is RATEPERUNIT.  # noqa: E501

        :return: The rate_per_unit of this EarningsRate.  # noqa: E501
        :rtype: str
        """
        return self._rate_per_unit

    @rate_per_unit.setter
    def rate_per_unit(self, rate_per_unit):
        """Sets the rate_per_unit of this EarningsRate.

        Default rate per unit (optional). Only applicable if RateType is RATEPERUNIT.  # noqa: E501

        :param rate_per_unit: The rate_per_unit of this EarningsRate.  # noqa: E501
        :type: str
        """

        self._rate_per_unit = rate_per_unit

    @property
    def multiplier(self):
        """Gets the multiplier of this EarningsRate.  # noqa: E501

        This is the multiplier used to calculate the rate per unit, based on the employee’s ordinary earnings rate. For example, for time and a half enter 1.5. Only applicable if RateType is MULTIPLE  # noqa: E501

        :return: The multiplier of this EarningsRate.  # noqa: E501
        :rtype: float
        """
        return self._multiplier

    @multiplier.setter
    def multiplier(self, multiplier):
        """Sets the multiplier of this EarningsRate.

        This is the multiplier used to calculate the rate per unit, based on the employee’s ordinary earnings rate. For example, for time and a half enter 1.5. Only applicable if RateType is MULTIPLE  # noqa: E501

        :param multiplier: The multiplier of this EarningsRate.  # noqa: E501
        :type: float
        """

        self._multiplier = multiplier

    @property
    def accrue_leave(self):
        """Gets the accrue_leave of this EarningsRate.  # noqa: E501

        Indicates that this earnings rate should accrue leave. Only applicable if RateType is MULTIPLE  # noqa: E501

        :return: The accrue_leave of this EarningsRate.  # noqa: E501
        :rtype: bool
        """
        return self._accrue_leave

    @accrue_leave.setter
    def accrue_leave(self, accrue_leave):
        """Sets the accrue_leave of this EarningsRate.

        Indicates that this earnings rate should accrue leave. Only applicable if RateType is MULTIPLE  # noqa: E501

        :param accrue_leave: The accrue_leave of this EarningsRate.  # noqa: E501
        :type: bool
        """

        self._accrue_leave = accrue_leave

    @property
    def amount(self):
        """Gets the amount of this EarningsRate.  # noqa: E501

        Optional Amount for FIXEDAMOUNT RateType EarningsRate  # noqa: E501

        :return: The amount of this EarningsRate.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this EarningsRate.

        Optional Amount for FIXEDAMOUNT RateType EarningsRate  # noqa: E501

        :param amount: The amount of this EarningsRate.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def employment_termination_payment_type(self):
        """Gets the employment_termination_payment_type of this EarningsRate.  # noqa: E501


        :return: The employment_termination_payment_type of this EarningsRate.  # noqa: E501
        :rtype: EmploymentTerminationPaymentType
        """
        return self._employment_termination_payment_type

    @employment_termination_payment_type.setter
    def employment_termination_payment_type(self, employment_termination_payment_type):
        """Sets the employment_termination_payment_type of this EarningsRate.


        :param employment_termination_payment_type: The employment_termination_payment_type of this EarningsRate.  # noqa: E501
        :type: EmploymentTerminationPaymentType
        """

        self._employment_termination_payment_type = employment_termination_payment_type

    @property
    def updated_date_utc(self):
        """Gets the updated_date_utc of this EarningsRate.  # noqa: E501

        Last modified timestamp  # noqa: E501

        :return: The updated_date_utc of this EarningsRate.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_date_utc

    @updated_date_utc.setter
    def updated_date_utc(self, updated_date_utc):
        """Sets the updated_date_utc of this EarningsRate.

        Last modified timestamp  # noqa: E501

        :param updated_date_utc: The updated_date_utc of this EarningsRate.  # noqa: E501
        :type: datetime
        """

        self._updated_date_utc = updated_date_utc

    @property
    def current_record(self):
        """Gets the current_record of this EarningsRate.  # noqa: E501

        Is the current record  # noqa: E501

        :return: The current_record of this EarningsRate.  # noqa: E501
        :rtype: bool
        """
        return self._current_record

    @current_record.setter
    def current_record(self, current_record):
        """Sets the current_record of this EarningsRate.

        Is the current record  # noqa: E501

        :param current_record: The current_record of this EarningsRate.  # noqa: E501
        :type: bool
        """

        self._current_record = current_record

    @property
    def allowance_type(self):
        """Gets the allowance_type of this EarningsRate.  # noqa: E501


        :return: The allowance_type of this EarningsRate.  # noqa: E501
        :rtype: AllowanceType
        """
        return self._allowance_type

    @allowance_type.setter
    def allowance_type(self, allowance_type):
        """Sets the allowance_type of this EarningsRate.


        :param allowance_type: The allowance_type of this EarningsRate.  # noqa: E501
        :type: AllowanceType
        """

        self._allowance_type = allowance_type



# coding: utf-8

"""
    Xero Payroll UK

    This is the Xero Payroll API for orgs in the UK region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class Reimbursement(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "reimbursement_id": "str",
        "name": "str",
        "account_id": "str",
        "current_record": "bool",
    }

    attribute_map = {
        "reimbursement_id": "reimbursementID",
        "name": "name",
        "account_id": "accountID",
        "current_record": "currentRecord",
    }

    def __init__(
        self, reimbursement_id=None, name=None, account_id=None, current_record=None
    ):  # noqa: E501
        """Reimbursement - a model defined in OpenAPI"""  # noqa: E501

        self._reimbursement_id = None
        self._name = None
        self._account_id = None
        self._current_record = None
        self.discriminator = None

        if reimbursement_id is not None:
            self.reimbursement_id = reimbursement_id
        self.name = name
        self.account_id = account_id
        if current_record is not None:
            self.current_record = current_record

    @property
    def reimbursement_id(self):
        """Gets the reimbursement_id of this Reimbursement.  # noqa: E501

        Xero unique identifier for a reimbursement  # noqa: E501

        :return: The reimbursement_id of this Reimbursement.  # noqa: E501
        :rtype: str
        """
        return self._reimbursement_id

    @reimbursement_id.setter
    def reimbursement_id(self, reimbursement_id):
        """Sets the reimbursement_id of this Reimbursement.

        Xero unique identifier for a reimbursement  # noqa: E501

        :param reimbursement_id: The reimbursement_id of this Reimbursement.  # noqa: E501
        :type: str
        """

        self._reimbursement_id = reimbursement_id

    @property
    def name(self):
        """Gets the name of this Reimbursement.  # noqa: E501

        Name of the reimbursement  # noqa: E501

        :return: The name of this Reimbursement.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Reimbursement.

        Name of the reimbursement  # noqa: E501

        :param name: The name of this Reimbursement.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError(
                "Invalid value for `name`, must not be `None`"
            )  # noqa: E501

        self._name = name

    @property
    def account_id(self):
        """Gets the account_id of this Reimbursement.  # noqa: E501

        Xero unique identifier for the account used for the reimbursement  # noqa: E501

        :return: The account_id of this Reimbursement.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this Reimbursement.

        Xero unique identifier for the account used for the reimbursement  # noqa: E501

        :param account_id: The account_id of this Reimbursement.  # noqa: E501
        :type: str
        """
        if account_id is None:
            raise ValueError(
                "Invalid value for `account_id`, must not be `None`"
            )  # noqa: E501

        self._account_id = account_id

    @property
    def current_record(self):
        """Gets the current_record of this Reimbursement.  # noqa: E501

        Indicates that whether the reimbursement is active  # noqa: E501

        :return: The current_record of this Reimbursement.  # noqa: E501
        :rtype: bool
        """
        return self._current_record

    @current_record.setter
    def current_record(self, current_record):
        """Sets the current_record of this Reimbursement.

        Indicates that whether the reimbursement is active  # noqa: E501

        :param current_record: The current_record of this Reimbursement.  # noqa: E501
        :type: bool
        """

        self._current_record = current_record



# coding: utf-8

"""
    Xero Payroll AU API

    This is the Xero Payroll API for orgs in Australia region.  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class LeaveLine(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        "leave_type_id": "str",
        "calculation_type": "LeaveLineCalculationType",
        "entitlement_final_pay_payout_type": "EntitlementFinalPayPayoutType",
        "employment_termination_payment_type": "EmploymentTerminationPaymentType",
        "include_superannuation_guarantee_contribution": "bool",
        "number_of_units": "float",
        "annual_number_of_units": "float",
        "full_time_number_of_units_per_period": "float",
    }

    attribute_map = {
        "leave_type_id": "LeaveTypeID",
        "calculation_type": "CalculationType",
        "entitlement_final_pay_payout_type": "EntitlementFinalPayPayoutType",
        "employment_termination_payment_type": "EmploymentTerminationPaymentType",
        "include_superannuation_guarantee_contribution": "IncludeSuperannuationGuaranteeContribution",
        "number_of_units": "NumberOfUnits",
        "annual_number_of_units": "AnnualNumberOfUnits",
        "full_time_number_of_units_per_period": "FullTimeNumberOfUnitsPerPeriod",
    }

    def __init__(
        self,
        leave_type_id=None,
        calculation_type=None,
        entitlement_final_pay_payout_type=None,
        employment_termination_payment_type=None,
        include_superannuation_guarantee_contribution=None,
        number_of_units=None,
        annual_number_of_units=None,
        full_time_number_of_units_per_period=None,
    ):  # noqa: E501
        """LeaveLine - a model defined in OpenAPI"""  # noqa: E501

        self._leave_type_id = None
        self._calculation_type = None
        self._entitlement_final_pay_payout_type = None
        self._employment_termination_payment_type = None
        self._include_superannuation_guarantee_contribution = None
        self._number_of_units = None
        self._annual_number_of_units = None
        self._full_time_number_of_units_per_period = None
        self.discriminator = None

        if leave_type_id is not None:
            self.leave_type_id = leave_type_id
        if calculation_type is not None:
            self.calculation_type = calculation_type
        if entitlement_final_pay_payout_type is not None:
            self.entitlement_final_pay_payout_type = entitlement_final_pay_payout_type
        if employment_termination_payment_type is not None:
            self.employment_termination_payment_type = (
                employment_termination_payment_type
            )
        if include_superannuation_guarantee_contribution is not None:
            self.include_superannuation_guarantee_contribution = (
                include_superannuation_guarantee_contribution
            )
        if number_of_units is not None:
            self.number_of_units = number_of_units
        if annual_number_of_units is not None:
            self.annual_number_of_units = annual_number_of_units
        if full_time_number_of_units_per_period is not None:
            self.full_time_number_of_units_per_period = (
                full_time_number_of_units_per_period
            )

    @property
    def leave_type_id(self):
        """Gets the leave_type_id of this LeaveLine.  # noqa: E501

        Xero leave type identifier  # noqa: E501

        :return: The leave_type_id of this LeaveLine.  # noqa: E501
        :rtype: str
        """
        return self._leave_type_id

    @leave_type_id.setter
    def leave_type_id(self, leave_type_id):
        """Sets the leave_type_id of this LeaveLine.

        Xero leave type identifier  # noqa: E501

        :param leave_type_id: The leave_type_id of this LeaveLine.  # noqa: E501
        :type: str
        """

        self._leave_type_id = leave_type_id

    @property
    def calculation_type(self):
        """Gets the calculation_type of this LeaveLine.  # noqa: E501


        :return: The calculation_type of this LeaveLine.  # noqa: E501
        :rtype: LeaveLineCalculationType
        """
        return self._calculation_type

    @calculation_type.setter
    def calculation_type(self, calculation_type):
        """Sets the calculation_type of this LeaveLine.


        :param calculation_type: The calculation_type of this LeaveLine.  # noqa: E501
        :type: LeaveLineCalculationType
        """

        self._calculation_type = calculation_type

    @property
    def entitlement_final_pay_payout_type(self):
        """Gets the entitlement_final_pay_payout_type of this LeaveLine.  # noqa: E501


        :return: The entitlement_final_pay_payout_type of this LeaveLine.  # noqa: E501
        :rtype: EntitlementFinalPayPayoutType
        """
        return self._entitlement_final_pay_payout_type

    @entitlement_final_pay_payout_type.setter
    def entitlement_final_pay_payout_type(self, entitlement_final_pay_payout_type):
        """Sets the entitlement_final_pay_payout_type of this LeaveLine.


        :param entitlement_final_pay_payout_type: The entitlement_final_pay_payout_type of this LeaveLine.  # noqa: E501
        :type: EntitlementFinalPayPayoutType
        """

        self._entitlement_final_pay_payout_type = entitlement_final_pay_payout_type

    @property
    def employment_termination_payment_type(self):
        """Gets the employment_termination_payment_type of this LeaveLine.  # noqa: E501


        :return: The employment_termination_payment_type of this LeaveLine.  # noqa: E501
        :rtype: EmploymentTerminationPaymentType
        """
        return self._employment_termination_payment_type

    @employment_termination_payment_type.setter
    def employment_termination_payment_type(self, employment_termination_payment_type):
        """Sets the employment_termination_payment_type of this LeaveLine.


        :param employment_termination_payment_type: The employment_termination_payment_type of this LeaveLine.  # noqa: E501
        :type: EmploymentTerminationPaymentType
        """

        self._employment_termination_payment_type = employment_termination_payment_type

    @property
    def include_superannuation_guarantee_contribution(self):
        """Gets the include_superannuation_guarantee_contribution of this LeaveLine.  # noqa: E501

        amount of leave line  # noqa: E501

        :return: The include_superannuation_guarantee_contribution of this LeaveLine.  # noqa: E501
        :rtype: bool
        """
        return self._include_superannuation_guarantee_contribution

    @include_superannuation_guarantee_contribution.setter
    def include_superannuation_guarantee_contribution(
        self, include_superannuation_guarantee_contribution
    ):
        """Sets the include_superannuation_guarantee_contribution of this LeaveLine.

        amount of leave line  # noqa: E501

        :param include_superannuation_guarantee_contribution: The include_superannuation_guarantee_contribution of this LeaveLine.  # noqa: E501
        :type: bool
        """

        self._include_superannuation_guarantee_contribution = (
            include_superannuation_guarantee_contribution
        )

    @property
    def number_of_units(self):
        """Gets the number_of_units of this LeaveLine.  # noqa: E501

        Number of units for leave line.  # noqa: E501

        :return: The number_of_units of this LeaveLine.  # noqa: E501
        :rtype: float
        """
        return self._number_of_units

    @number_of_units.setter
    def number_of_units(self, number_of_units):
        """Sets the number_of_units of this LeaveLine.

        Number of units for leave line.  # noqa: E501

        :param number_of_units: The number_of_units of this LeaveLine.  # noqa: E501
        :type: float
        """

        self._number_of_units = number_of_units

    @property
    def annual_number_of_units(self):
        """Gets the annual_number_of_units of this LeaveLine.  # noqa: E501

        Hours of leave accrued each year  # noqa: E501

        :return: The annual_number_of_units of this LeaveLine.  # noqa: E501
        :rtype: float
        """
        return self._annual_number_of_units

    @annual_number_of_units.setter
    def annual_number_of_units(self, annual_number_of_units):
        """Sets the annual_number_of_units of this LeaveLine.

        Hours of leave accrued each year  # noqa: E501

        :param annual_number_of_units: The annual_number_of_units of this LeaveLine.  # noqa: E501
        :type: float
        """

        self._annual_number_of_units = annual_number_of_units

    @property
    def full_time_number_of_units_per_period(self):
        """Gets the full_time_number_of_units_per_period of this LeaveLine.  # noqa: E501

        Normal ordinary earnings number of units for leave line.  # noqa: E501

        :return: The full_time_number_of_units_per_period of this LeaveLine.  # noqa: E501
        :rtype: float
        """
        return self._full_time_number_of_units_per_period

    @full_time_number_of_units_per_period.setter
    def full_time_number_of_units_per_period(
        self, full_time_number_of_units_per_period
    ):
        """Sets the full_time_number_of_units_per_period of this LeaveLine.

        Normal ordinary earnings number of units for leave line.  # noqa: E501

        :param full_time_number_of_units_per_period: The full_time_number_of_units_per_period of this LeaveLine.  # noqa: E501
        :type: float
        """

        self._full_time_number_of_units_per_period = (
            full_time_number_of_units_per_period
        )



# -*- coding: utf-8 -*-
import pprint
from functools import singledispatch


class BaseModel:
    """"""

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {}  # child model to define specific mappings

    attribute_map = {}  # child model to define specific mappings

    def to_dict(self):
        """Returns the model properties as a dict"""
        return {
            key: serialize_to_dict(getattr(self, key))
            for key in self.openapi_types.keys()
        }

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, type(self)):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other


@singledispatch
def serialize_to_dict(value):
    return value


@serialize_to_dict.register(BaseModel)
def serialize_model_to_dict(value):
    return value.to_dict()


@serialize_to_dict.register(list)
def serialize_list_to_dict(value):
    return [serialize_to_dict(item) for item in value]


@serialize_to_dict.register(tuple)
def serialize_tuple_to_dict(value):
    return tuple(serialize_to_dict(item) for item in value)


@serialize_to_dict.register(dict)
def serialize_dict_to_dict(value):
    return {key: serialize_to_dict(val) for key, val in value.items()}



# coding: utf-8

"""
    Xero Accounting API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    Contact: api@xero.com
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401

from xero_python.models import BaseModel


class PaymentDelete(BaseModel):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {"status": "str"}

    attribute_map = {"status": "Status"}

    def __init__(self, status="DELETED"):  # noqa: E501
        """PaymentDelete - a model defined in OpenAPI"""  # noqa: E501

        self._status = None
        self.discriminator = None

        self.status = status

    @property
    def status(self):
        """Gets the status of this PaymentDelete.  # noqa: E501

        The status of the payment.  # noqa: E501

        :return: The status of this PaymentDelete.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this PaymentDelete.

        The status of the payment.  # noqa: E501

        :param status: The status of this PaymentDelete.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError(
                "Invalid value for `status`, must not be `None`"
            )  # noqa: E501

        self._status = status
